summaryrefslogtreecommitdiff
path: root/sfx2/source
diff options
context:
space:
mode:
authorMikhail Voytenko <mav@openoffice.org>2011-01-10 16:07:18 +0100
committerMikhail Voytenko <mav@openoffice.org>2011-01-10 16:07:18 +0100
commit3f4e9b4c3cd9028744ea6ed5e93c41c51a15d229 (patch)
tree65f4fe38cd7c7ba5805435393b299eb0b8ff31c6 /sfx2/source
parent61a8280d645fe1b6957591d5d338d073040e8b2e (diff)
removetooltypes01: #i112600# remove tooltypes from sfx2
Diffstat (limited to 'sfx2/source')
-rw-r--r--sfx2/source/appl/appchild.cxx12
-rw-r--r--sfx2/source/appl/appreg.cxx10
-rw-r--r--sfx2/source/appl/helpinterceptor.hxx2
-rw-r--r--sfx2/source/appl/newhelp.hxx8
-rw-r--r--sfx2/source/appl/sfxhelp.cxx14
-rw-r--r--sfx2/source/appl/sfxpicklist.cxx12
-rw-r--r--sfx2/source/appl/shutdowniconunx.cxx18
-rw-r--r--sfx2/source/bastyp/bitset.cxx84
-rw-r--r--sfx2/source/bastyp/helper.cxx26
-rw-r--r--sfx2/source/bastyp/minarray.cxx156
-rw-r--r--sfx2/source/bastyp/misc.cxx2
-rw-r--r--sfx2/source/bastyp/sfxresid.cxx4
-rw-r--r--sfx2/source/control/ctrlitem.cxx20
-rw-r--r--sfx2/source/control/minfitem.cxx2
-rw-r--r--sfx2/source/control/msgpool.cxx48
-rw-r--r--sfx2/source/control/querystatus.cxx8
-rw-r--r--sfx2/source/control/sfxstatuslistener.cxx6
-rw-r--r--sfx2/source/dialog/about.cxx18
-rw-r--r--sfx2/source/dialog/filedlghelper.cxx16
-rw-r--r--sfx2/source/dialog/filedlgimpl.hxx2
-rw-r--r--sfx2/source/dialog/passwd.cxx4
-rw-r--r--sfx2/source/dialog/styfitem.cxx16
-rw-r--r--sfx2/source/dialog/tplpitem.cxx12
-rw-r--r--sfx2/source/doc/docfac.cxx6
-rw-r--r--sfx2/source/doc/docinsert.cxx16
-rw-r--r--sfx2/source/doc/doctdlg.cxx18
-rw-r--r--sfx2/source/doc/doctempl.cxx12
-rw-r--r--sfx2/source/doc/objembed.cxx12
-rw-r--r--sfx2/source/doc/objitem.cxx14
-rw-r--r--sfx2/source/doc/objxtor.cxx14
-rw-r--r--sfx2/source/doc/plugin.cxx12
-rwxr-xr-xsfx2/source/doc/printhelper.cxx4
-rw-r--r--sfx2/source/explorer/nochaos.cxx6
-rw-r--r--sfx2/source/inc/appbas.hxx2
-rw-r--r--sfx2/source/inc/helper.hxx2
-rw-r--r--sfx2/source/inc/mnucfga.hxx2
-rw-r--r--sfx2/source/inc/nochaos.hxx2
-rw-r--r--sfx2/source/inc/objmnctl.hxx4
-rw-r--r--sfx2/source/inc/sfxpicklist.hxx4
-rw-r--r--sfx2/source/inc/slotserv.hxx12
-rw-r--r--sfx2/source/inc/tplcitem.hxx6
-rwxr-xr-xsfx2/source/menu/thessubmenu.cxx8
-rw-r--r--sfx2/source/menu/thessubmenu.hxx4
-rw-r--r--sfx2/source/view/frmload.cxx16
-rw-r--r--sfx2/source/view/userinputinterception.cxx2
-rw-r--r--sfx2/source/view/viewfac.cxx2
-rw-r--r--sfx2/source/view/viewimp.hxx6
47 files changed, 343 insertions, 343 deletions
diff --git a/sfx2/source/appl/appchild.cxx b/sfx2/source/appl/appchild.cxx
index b18fc905abdc..ea7b331b839b 100644
--- a/sfx2/source/appl/appchild.cxx
+++ b/sfx2/source/appl/appchild.cxx
@@ -61,7 +61,7 @@ void SfxApplication::RegisterChildWindow_Impl( SfxModule *pMod, SfxChildWinFacto
pAppData_Impl->pFactArr = new SfxChildWinFactArr_Impl;
//#ifdef DBG_UTIL
- for (USHORT nFactory=0; nFactory<pAppData_Impl->pFactArr->Count(); ++nFactory)
+ for (sal_uInt16 nFactory=0; nFactory<pAppData_Impl->pFactArr->Count(); ++nFactory)
{
if (pFact->nId == (*pAppData_Impl->pFactArr)[nFactory]->nId)
{
@@ -76,7 +76,7 @@ void SfxApplication::RegisterChildWindow_Impl( SfxModule *pMod, SfxChildWinFacto
SfxChildWinFactory, pFact, pAppData_Impl->pFactArr->Count() );
}
-void SfxApplication::RegisterChildWindowContext_Impl( SfxModule *pMod, USHORT nId,
+void SfxApplication::RegisterChildWindowContext_Impl( SfxModule *pMod, sal_uInt16 nId,
SfxChildWinContextFactory *pFact)
{
SfxChildWinFactArr_Impl *pFactories;
@@ -87,8 +87,8 @@ void SfxApplication::RegisterChildWindowContext_Impl( SfxModule *pMod, USHORT nI
pFactories = pMod->GetChildWinFactories_Impl();
if ( pFactories )
{
- USHORT nCount = pFactories->Count();
- for (USHORT nFactory=0; nFactory<nCount; ++nFactory)
+ sal_uInt16 nCount = pFactories->Count();
+ for (sal_uInt16 nFactory=0; nFactory<nCount; ++nFactory)
{
SfxChildWinFactory *pFac = (*pFactories)[nFactory];
if ( nId == pFac->nId )
@@ -108,8 +108,8 @@ void SfxApplication::RegisterChildWindowContext_Impl( SfxModule *pMod, USHORT nI
DBG_ASSERT( pAppData_Impl->pFactArr, "Keine Factories!" );
pFactories = pAppData_Impl->pFactArr;
- USHORT nCount = pFactories->Count();
- for (USHORT nFactory=0; nFactory<nCount; ++nFactory)
+ sal_uInt16 nCount = pFactories->Count();
+ for (sal_uInt16 nFactory=0; nFactory<nCount; ++nFactory)
{
SfxChildWinFactory *pFac = (*pFactories)[nFactory];
if ( nId == pFac->nId )
diff --git a/sfx2/source/appl/appreg.cxx b/sfx2/source/appl/appreg.cxx
index 9fd2dfc696d3..dfecc21f9d4b 100644
--- a/sfx2/source/appl/appreg.cxx
+++ b/sfx2/source/appl/appreg.cxx
@@ -65,9 +65,9 @@ void SfxApplication::Registrations_Impl()
// ChildWindows
SfxRecordingFloatWrapper_Impl::RegisterChildWindow();
- SfxNavigatorWrapper::RegisterChildWindow( FALSE, NULL, SFX_CHILDWIN_NEVERHIDE );
+ SfxNavigatorWrapper::RegisterChildWindow( sal_False, NULL, SFX_CHILDWIN_NEVERHIDE );
SfxPartChildWnd_Impl::RegisterChildWindow();
- SfxTemplateDialogWrapper::RegisterChildWindow(TRUE);
+ SfxTemplateDialogWrapper::RegisterChildWindow(sal_True);
SfxDockingWrapper::RegisterChildWindow();
// Controller
@@ -88,7 +88,7 @@ void SfxApplication::RegisterToolBoxControl_Impl( SfxModule *pMod, SfxTbxCtrlFac
}
#ifdef DBG_UTIL
- for ( USHORT n=0; n<pAppData_Impl->pTbxCtrlFac->Count(); n++ )
+ for ( sal_uInt16 n=0; n<pAppData_Impl->pTbxCtrlFac->Count(); n++ )
{
SfxTbxCtrlFactory *pF = (*pAppData_Impl->pTbxCtrlFac)[n];
if ( pF->nTypeId && pF->nTypeId == pFact->nTypeId &&
@@ -113,7 +113,7 @@ void SfxApplication::RegisterStatusBarControl_Impl( SfxModule *pMod, SfxStbCtrlF
}
#ifdef DBG_UTIL
- for ( USHORT n=0; n<pAppData_Impl->pStbCtrlFac->Count(); n++ )
+ for ( sal_uInt16 n=0; n<pAppData_Impl->pStbCtrlFac->Count(); n++ )
{
SfxStbCtrlFactory *pF = (*pAppData_Impl->pStbCtrlFac)[n];
if ( pF->nTypeId && pF->nTypeId == pFact->nTypeId &&
@@ -138,7 +138,7 @@ void SfxApplication::RegisterMenuControl_Impl( SfxModule *pMod, SfxMenuCtrlFacto
}
#ifdef DBG_UTIL
- for ( USHORT n=0; n<pAppData_Impl->pMenuCtrlFac->Count(); n++ )
+ for ( sal_uInt16 n=0; n<pAppData_Impl->pMenuCtrlFac->Count(); n++ )
{
SfxMenuCtrlFactory *pF = (*pAppData_Impl->pMenuCtrlFac)[n];
if ( pF->nTypeId && pF->nTypeId == pFact->nTypeId &&
diff --git a/sfx2/source/appl/helpinterceptor.hxx b/sfx2/source/appl/helpinterceptor.hxx
index 3476f0d305b5..5a6f0d024c20 100644
--- a/sfx2/source/appl/helpinterceptor.hxx
+++ b/sfx2/source/appl/helpinterceptor.hxx
@@ -75,7 +75,7 @@ friend class SfxHelpWindow_Impl;
HelpHistoryList_Impl* m_pHistory;
SfxHelpWindow_Impl* m_pWindow;
- ULONG m_nCurPos;
+ sal_uIntPtr m_nCurPos;
String m_aCurrentURL;
com::sun::star::uno::Any m_aViewData;
diff --git a/sfx2/source/appl/newhelp.hxx b/sfx2/source/appl/newhelp.hxx
index 95a5bfe52230..fb34640f93ef 100644
--- a/sfx2/source/appl/newhelp.hxx
+++ b/sfx2/source/appl/newhelp.hxx
@@ -64,7 +64,7 @@ private:
String m_sURL;
public:
- OpenStatusListener_Impl() : m_bFinished( FALSE ), m_bSuccess( FALSE ) {}
+ OpenStatusListener_Impl() : m_bFinished( sal_False ), m_bSuccess( sal_False ) {}
virtual void SAL_CALL dispatchFinished( const ::com::sun::star::frame::DispatchResultEvent& Event ) throw(::com::sun::star::uno::RuntimeException);
virtual void SAL_CALL disposing( const ::com::sun::star::lang::EventObject& Source ) throw(::com::sun::star::uno::RuntimeException);
@@ -267,7 +267,7 @@ public:
class BookmarksBox_Impl : public ListBox
{
private:
- void DoAction( USHORT nAction );
+ void DoAction( sal_uInt16 nAction );
public:
BookmarksBox_Impl( Window* pParent, const ResId& rResId );
@@ -331,7 +331,7 @@ private:
void Initialize();
void SetActiveFactory();
- HelpTabPage_Impl* GetCurrentPage( USHORT& rCurId );
+ HelpTabPage_Impl* GetCurrentPage( sal_uInt16& rCurId );
inline ContentTabPage_Impl* GetContentPage();
inline IndexTabPage_Impl* GetIndexPage();
@@ -566,7 +566,7 @@ public:
void SetFactory( const String& rFactory );
void SetHelpURL( const String& rURL );
- void DoAction( USHORT nActionId );
+ void DoAction( sal_uInt16 nActionId );
void CloseWindow();
void UpdateToolbox();
diff --git a/sfx2/source/appl/sfxhelp.cxx b/sfx2/source/appl/sfxhelp.cxx
index bab37281cb05..855369c11bc9 100644
--- a/sfx2/source/appl/sfxhelp.cxx
+++ b/sfx2/source/appl/sfxhelp.cxx
@@ -190,7 +190,7 @@ sal_Bool GetHelpAnchor_Impl( const String& _rURL, String& _rAnchor )
// --> OD 2009-07-01 #159496#
// do not release solar mutex due to crash regarding accessibility
-// ULONG nSolarCount = Application::ReleaseSolarMutex();
+// sal_uIntPtr nSolarCount = Application::ReleaseSolarMutex();
// <--
try
{
@@ -901,17 +901,17 @@ XubString SfxHelp::GetHelpText( const String& aCommandURL, const Window* pWindow
return sHelpText;
}
-BOOL SfxHelp::SearchKeyword( const XubString& rKeyword )
+sal_Bool SfxHelp::SearchKeyword( const XubString& rKeyword )
{
return Start_Impl( String(), NULL, rKeyword );
}
-BOOL SfxHelp::Start( const String& rURL, const Window* pWindow )
+sal_Bool SfxHelp::Start( const String& rURL, const Window* pWindow )
{
return Start_Impl( rURL, pWindow, String() );
}
-BOOL SfxHelp::Start_Impl( const String& rURL, const Window* pWindow, const String& rKeyword )
+sal_Bool SfxHelp::Start_Impl( const String& rURL, const Window* pWindow, const String& rKeyword )
{
// check if help is available
String aHelpRootURL( DEFINE_CONST_OUSTRING("vnd.sun.star.help://") );
@@ -922,7 +922,7 @@ BOOL SfxHelp::Start_Impl( const String& rURL, const Window* pWindow, const Strin
// no factories -> no help -> error message and return
NoHelpErrorBox aErrBox( const_cast< Window* >( pWindow ) );
aErrBox.Execute();
- return FALSE;
+ return sal_False;
}
/* rURL may be
@@ -992,7 +992,7 @@ BOOL SfxHelp::Start_Impl( const String& rURL, const Window* pWindow, const Strin
else
pHelpWindow = (SfxHelpWindow_Impl*)VCLUnoHelper::GetWindow(xHelp->getComponentWindow());
if (!xHelp.is() || !xHelpContent.is() || !pHelpWindow)
- return FALSE;
+ return sal_False;
#ifdef DBG_UTIL
ByteString aTmp("SfxHelp: HelpId = ");
@@ -1009,7 +1009,7 @@ BOOL SfxHelp::Start_Impl( const String& rURL, const Window* pWindow, const Strin
if ( xTopWindow.is() )
xTopWindow->toFront();
- return TRUE;
+ return sal_True;
}
String SfxHelp::CreateHelpURL( const String& aCommandURL, const String& rModuleName )
diff --git a/sfx2/source/appl/sfxpicklist.cxx b/sfx2/source/appl/sfxpicklist.cxx
index 0074faac192f..59a753fdb2c4 100644
--- a/sfx2/source/appl/sfxpicklist.cxx
+++ b/sfx2/source/appl/sfxpicklist.cxx
@@ -100,7 +100,7 @@ osl::Mutex* SfxPickList::GetOrCreateMutex()
return pMutex;
}
-void SfxPickList::CreatePicklistMenuTitle( Menu* pMenu, USHORT nItemId, const String& aURLString, sal_uInt32 nNo )
+void SfxPickList::CreatePicklistMenuTitle( Menu* pMenu, sal_uInt16 nItemId, const String& aURLString, sal_uInt32 nNo )
{
String aPickEntry;
@@ -292,8 +292,8 @@ void SfxPickList::CreateMenuEntries( Menu* pMenu )
{
PickListEntry* pEntry = GetPickListEntry( i );
- pMenu->InsertItem( (USHORT)(START_ITEMID_PICKLIST + i), aEmptyString );
- CreatePicklistMenuTitle( pMenu, (USHORT)(START_ITEMID_PICKLIST + i), pEntry->aName, i );
+ pMenu->InsertItem( (sal_uInt16)(START_ITEMID_PICKLIST + i), aEmptyString );
+ CreatePicklistMenuTitle( pMenu, (sal_uInt16)(START_ITEMID_PICKLIST + i), pEntry->aName, i );
}
bPickListMenuInitializing = sal_False;
@@ -314,7 +314,7 @@ void SfxPickList::ExecuteEntry( sal_uInt32 nIndex )
String aFilter( pPick->aFilter );
aGuard.clear();
- USHORT nPos=aFilter.Search('|');
+ sal_uInt16 nPos=aFilter.Search('|');
if( nPos != STRING_NOTFOUND )
{
String aOptions(aFilter.Copy( nPos ).GetBuffer()+1);
@@ -328,7 +328,7 @@ void SfxPickList::ExecuteEntry( sal_uInt32 nIndex )
}
}
-void SfxPickList::ExecuteMenuEntry( USHORT nId )
+void SfxPickList::ExecuteMenuEntry( sal_uInt16 nId )
{
ExecuteEntry( (sal_uInt32)( nId - START_ITEMID_PICKLIST ) );
}
@@ -446,7 +446,7 @@ void SfxPickList::Notify( SfxBroadcaster&, const SfxHint& rHint )
return;
// ignore hidden documents
- if ( !SfxViewFrame::GetFirst( pDocSh, TRUE ) )
+ if ( !SfxViewFrame::GetFirst( pDocSh, sal_True ) )
return;
::rtl::OUString aTitle = pDocSh->GetTitle(SFX_TITLE_PICKLIST);
diff --git a/sfx2/source/appl/shutdowniconunx.cxx b/sfx2/source/appl/shutdowniconunx.cxx
index b9799f5818b7..c9c9e06ae248 100644
--- a/sfx2/source/appl/shutdowniconunx.cxx
+++ b/sfx2/source/appl/shutdowniconunx.cxx
@@ -76,7 +76,7 @@ static void menu_deactivate_cb( GtkWidget *pMenu )
gtk_menu_popdown( GTK_MENU( pMenu ) );
}
-static GdkPixbuf * ResIdToPixbuf( USHORT nResId )
+static GdkPixbuf * ResIdToPixbuf( sal_uInt16 nResId )
{
ResId aResId( SV_ICON_SMALL_START + nResId, *pVCLResMgr );
BitmapEx aIcon( aResId );
@@ -120,7 +120,7 @@ static GdkPixbuf * ResIdToPixbuf( USHORT nResId )
pInSalAlpha.ReleaseAccess( pSalAlpha );
return gdk_pixbuf_new_from_data( pPixbufData,
- GDK_COLORSPACE_RGB, TRUE, 8,
+ GDK_COLORSPACE_RGB, sal_True, 8,
aSize.Width(), aSize.Height(),
aSize.Width() * 4,
(GdkPixbufDestroyNotify) g_free,
@@ -138,7 +138,7 @@ static void oustring_delete (gpointer data,
static void add_item( GtkMenuShell *pMenuShell, const char *pAsciiURL,
OUString *pOverrideLabel,
- USHORT nResId, GCallback pFnCallback )
+ sal_uInt16 nResId, GCallback pFnCallback )
{
OUString *pURL = new OUString (OStringToOUString( pAsciiURL,
RTL_TEXTENCODING_UTF8 ));
@@ -171,7 +171,7 @@ using namespace ::com::sun::star::lang;
using namespace ::com::sun::star::beans;
static void add_ugly_db_item( GtkMenuShell *pMenuShell, const char *pAsciiURL,
- USHORT nResId, GCallback pFnCallback )
+ sal_uInt16 nResId, GCallback pFnCallback )
{
SvtDynamicMenuOptions aOpt;
Sequence < Sequence < PropertyValue > > aMenu = aOpt.GetMenu( E_NEWMENU );
@@ -311,7 +311,7 @@ layout_menu( GtkMenu *menu,
else
(*y) += ebox->allocation.height;
- *push_in = TRUE;
+ *push_in = sal_True;
}
}
@@ -319,14 +319,14 @@ static gboolean display_menu_cb( GtkWidget *,
GdkEventButton *event, GtkWidget *pMenu )
{
if (event->button == 2)
- return FALSE;
+ return sal_False;
#ifdef TEMPLATE_DIALOG_MORE_POLISHED
if (event->button == 1 &&
event->type == GDK_2BUTTON_PRESS)
{
open_template_cb( NULL );
- return TRUE;
+ return sal_True;
}
if (event->button == 3)
{
@@ -338,7 +338,7 @@ static gboolean display_menu_cb( GtkWidget *,
gtk_menu_popup( GTK_MENU( pMenu ), NULL, NULL,
layout_menu, NULL, 0, event->time );
- return TRUE;
+ return sal_True;
}
extern "C" {
@@ -347,7 +347,7 @@ extern "C" {
{
::vos::OGuard aGuard( Application::GetSolarMutex() );
gtk_widget_show_all( GTK_WIDGET( pTrayIcon ) );
- return FALSE;
+ return sal_False;
}
}
diff --git a/sfx2/source/bastyp/bitset.cxx b/sfx2/source/bastyp/bitset.cxx
index df35593a9a18..995f6ccfdce4 100644
--- a/sfx2/source/bastyp/bitset.cxx
+++ b/sfx2/source/bastyp/bitset.cxx
@@ -39,7 +39,7 @@
//====================================================================
// add nOffset to each bit-value in the set
-BitSet BitSet::operator<<( USHORT nOffset ) const
+BitSet BitSet::operator<<( sal_uInt16 nOffset ) const
{
DBG_MEMTEST();
// create a work-copy, return it if nothing to shift
@@ -48,17 +48,17 @@ BitSet BitSet::operator<<( USHORT nOffset ) const
return aSet;
// compute the shiftment in long-words and bits
- USHORT nBlockDiff = nOffset / 32;
- ULONG nBitValDiff = nOffset % 32;
+ sal_uInt16 nBlockDiff = nOffset / 32;
+ sal_uIntPtr nBitValDiff = nOffset % 32;
// compute the new number of bits
- for ( USHORT nBlock = 0; nBlock < nBlockDiff; ++nBlock )
+ for ( sal_uInt16 nBlock = 0; nBlock < nBlockDiff; ++nBlock )
aSet.nCount = aSet.nCount - CountBits( *(aSet.pBitmap+nBlock) );
aSet.nCount = aSet.nCount -
CountBits( *(aSet.pBitmap+nBlockDiff) >> (32-nBitValDiff) );
// shift complete long-words
- USHORT nTarget, nSource;
+ sal_uInt16 nTarget, nSource;
for ( nTarget = 0, nSource = nBlockDiff;
(nSource+1) < aSet.nBlocks;
++nTarget, ++nSource )
@@ -76,7 +76,7 @@ BitSet BitSet::operator<<( USHORT nOffset ) const
// shorten the block-array
if ( nTarget < aSet.nBlocks )
{
- ULONG* pNewMap = new ULONG[nTarget];
+ sal_uIntPtr* pNewMap = new sal_uIntPtr[nTarget];
memcpy( pNewMap, aSet.pBitmap, 4 * nTarget );
delete [] aSet.pBitmap;
aSet.pBitmap = pNewMap;
@@ -90,7 +90,7 @@ BitSet BitSet::operator<<( USHORT nOffset ) const
// substracts nOffset from each bit-value in the set
-BitSet BitSet::operator>>( USHORT ) const
+BitSet BitSet::operator>>( sal_uInt16 ) const
{
DBG_MEMTEST();
return BitSet();
@@ -108,7 +108,7 @@ void BitSet::CopyFrom( const BitSet& rSet )
if ( rSet.nBlocks )
{
DBG_MEMTEST();
- pBitmap = new ULONG[nBlocks];
+ pBitmap = new sal_uIntPtr[nBlocks];
memcpy( pBitmap, rSet.pBitmap, 4 * nBlocks );
}
else
@@ -141,13 +141,13 @@ BitSet::BitSet( const BitSet& rOrig )
// creates a bitset from an array
-BitSet::BitSet( USHORT* pArray, USHORT nSize ):
+BitSet::BitSet( sal_uInt16* pArray, sal_uInt16 nSize ):
nCount(nSize)
{
DBG_MEMTEST();
// find the highest bit to set
- USHORT nMax = 0;
- for ( USHORT n = 0; n < nCount; ++n )
+ sal_uInt16 nMax = 0;
+ for ( sal_uInt16 n = 0; n < nCount; ++n )
if ( pArray[n] > nMax )
nMax = pArray[n];
@@ -156,15 +156,15 @@ BitSet::BitSet( USHORT* pArray, USHORT nSize ):
{
// allocate memory for all blocks needed
nBlocks = nMax / 32 + 1;
- pBitmap = new ULONG[nBlocks];
+ pBitmap = new sal_uIntPtr[nBlocks];
memset( pBitmap, 0, 4 * nBlocks );
// set all the bits
- for ( USHORT n = 0; n < nCount; ++n )
+ for ( sal_uInt16 n = 0; n < nCount; ++n )
{
// compute the block no. and bitvalue
- USHORT nBlock = n / 32;
- ULONG nBitVal = 1L << (n % 32);
+ sal_uInt16 nBlock = n / 32;
+ sal_uIntPtr nBitVal = 1L << (n % 32);
// set a single bit
if ( ( *(pBitmap+nBlock) & nBitVal ) == 0 )
@@ -220,16 +220,16 @@ BitSet& BitSet::operator=( const BitSet& rOrig )
// assignment from a single bit
-BitSet& BitSet::operator=( USHORT nBit )
+BitSet& BitSet::operator=( sal_uInt16 nBit )
{
DBG_MEMTEST();
delete [] pBitmap;
nBlocks = nBit / 32;
- ULONG nBitVal = 1L << (nBit % 32);
+ sal_uIntPtr nBitVal = 1L << (nBit % 32);
nCount = 1;
- pBitmap = new ULONG[nBlocks];
+ pBitmap = new sal_uIntPtr[nBlocks];
memset( pBitmap + nBlocks, 0, 4 * nBlocks );
*(pBitmap+nBlocks) = nBitVal;
@@ -241,11 +241,11 @@ BitSet& BitSet::operator=( USHORT nBit )
// creates the asymetric difference with another bitset
-BitSet& BitSet::operator-=(USHORT nBit)
+BitSet& BitSet::operator-=(sal_uInt16 nBit)
{
DBG_MEMTEST();
- USHORT nBlock = nBit / 32;
- ULONG nBitVal = 1L << (nBit % 32);
+ sal_uInt16 nBlock = nBit / 32;
+ sal_uIntPtr nBitVal = 1L << (nBit % 32);
if ( nBlock >= nBlocks )
return *this;
@@ -266,12 +266,12 @@ BitSet& BitSet::operator-=(USHORT nBit)
BitSet& BitSet::operator|=( const BitSet& rSet )
{
DBG_MEMTEST();
- USHORT nMax = Min(nBlocks, rSet.nBlocks);
+ sal_uInt16 nMax = Min(nBlocks, rSet.nBlocks);
// expand the bitmap
if ( nBlocks < rSet.nBlocks )
{
- ULONG *pNewMap = new ULONG[rSet.nBlocks];
+ sal_uIntPtr *pNewMap = new sal_uIntPtr[rSet.nBlocks];
memset( pNewMap + nBlocks, 0, 4 * (rSet.nBlocks - nBlocks) );
if ( pBitmap )
@@ -284,10 +284,10 @@ BitSet& BitSet::operator|=( const BitSet& rSet )
}
// add the bits blocks by block
- for ( USHORT nBlock = 0; nBlock < nMax; ++nBlock )
+ for ( sal_uInt16 nBlock = 0; nBlock < nMax; ++nBlock )
{
// compute numberof additional bits
- ULONG nDiff = ~*(pBitmap+nBlock) & *(rSet.pBitmap+nBlock);
+ sal_uIntPtr nDiff = ~*(pBitmap+nBlock) & *(rSet.pBitmap+nBlock);
nCount = nCount + CountBits(nDiff);
*(pBitmap+nBlock) |= *(rSet.pBitmap+nBlock);
@@ -300,15 +300,15 @@ BitSet& BitSet::operator|=( const BitSet& rSet )
// unites with a single bit
-BitSet& BitSet::operator|=( USHORT nBit )
+BitSet& BitSet::operator|=( sal_uInt16 nBit )
{
DBG_MEMTEST();
- USHORT nBlock = nBit / 32;
- ULONG nBitVal = 1L << (nBit % 32);
+ sal_uInt16 nBlock = nBit / 32;
+ sal_uIntPtr nBitVal = 1L << (nBit % 32);
if ( nBlock >= nBlocks )
{
- ULONG *pNewMap = new ULONG[nBlock+1];
+ sal_uIntPtr *pNewMap = new sal_uIntPtr[nBlock+1];
memset( pNewMap + nBlocks, 0, 4 * (nBlock - nBlocks + 1) );
if ( pBitmap )
@@ -333,14 +333,14 @@ BitSet& BitSet::operator|=( USHORT nBit )
// determines if the bit is set (may be the only one)
-BOOL BitSet::Contains( USHORT nBit ) const
+sal_Bool BitSet::Contains( sal_uInt16 nBit ) const
{
DBG_MEMTEST();
- USHORT nBlock = nBit / 32;
- ULONG nBitVal = 1L << (nBit % 32);
+ sal_uInt16 nBlock = nBit / 32;
+ sal_uIntPtr nBitVal = 1L << (nBit % 32);
if ( nBlock >= nBlocks )
- return FALSE;
+ return sal_False;
return ( nBitVal & *(pBitmap+nBlock) ) == nBitVal;
}
@@ -348,27 +348,27 @@ BOOL BitSet::Contains( USHORT nBit ) const
// determines if the bitsets are equal
-BOOL BitSet::operator==( const BitSet& rSet ) const
+sal_Bool BitSet::operator==( const BitSet& rSet ) const
{
DBG_MEMTEST();
if ( nBlocks != rSet.nBlocks )
- return FALSE;
+ return sal_False;
- USHORT nBlock = nBlocks;
+ sal_uInt16 nBlock = nBlocks;
while ( nBlock-- > 0 )
if ( *(pBitmap+nBlock) != *(rSet.pBitmap+nBlock) )
- return FALSE;
+ return sal_False;
- return TRUE;
+ return sal_True;
}
//--------------------------------------------------------------------
// counts the number of 1-bits in the parameter
-USHORT BitSet::CountBits( ULONG nBits )
+sal_uInt16 BitSet::CountBits( sal_uIntPtr nBits )
{
- USHORT nCount = 0;
+ sal_uInt16 nCount = 0;
int nBit = 32;
while ( nBit-- && nBits )
{ if ( ( (long)nBits ) < 0 )
@@ -380,9 +380,9 @@ USHORT BitSet::CountBits( ULONG nBits )
//--------------------------------------------------------------------
-USHORT IndexBitSet::GetFreeIndex()
+sal_uInt16 IndexBitSet::GetFreeIndex()
{
- for(USHORT i=0;i<USHRT_MAX;i++)
+ for(sal_uInt16 i=0;i<USHRT_MAX;i++)
if(!Contains(i))
{
*this|=i;
diff --git a/sfx2/source/bastyp/helper.cxx b/sfx2/source/bastyp/helper.cxx
index 091651fedbc2..3493981e5a25 100644
--- a/sfx2/source/bastyp/helper.cxx
+++ b/sfx2/source/bastyp/helper.cxx
@@ -335,10 +335,10 @@ uno::Sequence < OUString > SfxContentHelper::GetFolderContents( const String& rF
if ( pFiles )
{
- ULONG nCount = pFiles->Count();
+ sal_uIntPtr nCount = pFiles->Count();
uno::Sequence < OUString > aRet( nCount );
OUString* pRet = aRet.getArray();
- for ( ULONG i = 0; i < nCount; ++i )
+ for ( sal_uIntPtr i = 0; i < nCount; ++i )
{
OUString* pFile = pFiles->GetObject(i);
pRet[i] = *( pFile );
@@ -418,7 +418,7 @@ uno::Sequence < OUString > SfxContentHelper::GetFolderContentProperties( const S
pProperties = new StringList_Impl;
uno::Reference< sdbc::XRow > xRow( xResultSet, uno::UNO_QUERY );
uno::Reference< ucb::XContentAccess > xContentAccess( xResultSet, uno::UNO_QUERY );
- ULONG nFolderPos = LIST_APPEND;
+ sal_uIntPtr nFolderPos = LIST_APPEND;
try
{
@@ -442,7 +442,7 @@ uno::Sequence < OUString > SfxContentHelper::GetFolderContentProperties( const S
aRow += '\t';
aRow += bFolder ? '1' : '0';
OUString* pRow = new OUString( aRow );
- ULONG nPos = LIST_APPEND;
+ sal_uIntPtr nPos = LIST_APPEND;
if ( bFolder )
{
if ( LIST_APPEND == nFolderPos )
@@ -471,10 +471,10 @@ uno::Sequence < OUString > SfxContentHelper::GetFolderContentProperties( const S
if ( pProperties )
{
- ULONG nCount = pProperties->Count();
+ sal_uIntPtr nCount = pProperties->Count();
uno::Sequence < OUString > aRet( nCount );
OUString* pRet = aRet.getArray();
- for ( ULONG i = 0; i < nCount; ++i )
+ for ( sal_uIntPtr i = 0; i < nCount; ++i )
{
OUString* pProperty = pProperties->GetObject(i);
pRet[i] = *( pProperty );
@@ -564,10 +564,10 @@ uno::Sequence < OUString > SfxContentHelper::GetResultSet( const String& rURL )
if ( pList )
{
- ULONG nCount = pList->Count();
+ sal_uIntPtr nCount = pList->Count();
uno::Sequence < OUString > aRet( nCount );
OUString* pRet = aRet.getArray();
- for ( ULONG i = 0; i < nCount; ++i )
+ for ( sal_uIntPtr i = 0; i < nCount; ++i )
{
OUString* pEntry = pList->GetObject(i);
pRet[i] = *( pEntry );
@@ -647,10 +647,10 @@ uno::Sequence< OUString > SfxContentHelper::GetHelpTreeViewContents( const Strin
if ( pProperties )
{
- ULONG nCount = pProperties->Count();
+ sal_uIntPtr nCount = pProperties->Count();
uno::Sequence < OUString > aRet( nCount );
OUString* pRet = aRet.getArray();
- for ( ULONG i = 0; i < nCount; ++i )
+ for ( sal_uIntPtr i = 0; i < nCount; ++i )
{
OUString* pProperty = pProperties->GetObject(i);
pRet[i] = *( pProperty );
@@ -801,9 +801,9 @@ ErrCode SfxContentHelper::QueryDiskSpace( const String& rPath, sal_Int64& rFreeB
// -----------------------------------------------------------------------
-ULONG SfxContentHelper::GetSize( const String& rContent )
+sal_uIntPtr SfxContentHelper::GetSize( const String& rContent )
{
- ULONG nSize = 0;
+ sal_uIntPtr nSize = 0;
sal_Int64 nTemp = 0;
INetURLObject aObj( rContent );
DBG_ASSERT( aObj.GetProtocol() != INET_PROT_NOT_VALID, "Invalid URL!" );
@@ -820,7 +820,7 @@ ULONG SfxContentHelper::GetSize( const String& rContent )
{
DBG_ERRORFILE( "Any other exception" );
}
- nSize = (UINT32)nTemp;
+ nSize = (sal_uInt32)nTemp;
return nSize;
}
diff --git a/sfx2/source/bastyp/minarray.cxx b/sfx2/source/bastyp/minarray.cxx
index 978239239cea..9559de4069b0 100644
--- a/sfx2/source/bastyp/minarray.cxx
+++ b/sfx2/source/bastyp/minarray.cxx
@@ -35,13 +35,13 @@
// -----------------------------------------------------------------------
-SfxPtrArr::SfxPtrArr( BYTE nInitSize, BYTE nGrowSize ):
+SfxPtrArr::SfxPtrArr( sal_uInt8 nInitSize, sal_uInt8 nGrowSize ):
nUsed( 0 ),
nGrow( nGrowSize ? nGrowSize : 1 ),
nUnused( nInitSize )
{
DBG_MEMTEST();
- USHORT nMSCBug = nInitSize;
+ sal_uInt16 nMSCBug = nInitSize;
if ( nMSCBug > 0 )
pData = new void*[nMSCBug];
@@ -106,7 +106,7 @@ void SfxPtrArr::Append( void* aElem )
// musz das Array umkopiert werden?
if ( nUnused == 0 )
{
- USHORT nNewSize = (nUsed == 1) ? (nGrow==1 ? 2 : nGrow) : nUsed+nGrow;
+ sal_uInt16 nNewSize = (nUsed == 1) ? (nGrow==1 ? 2 : nGrow) : nUsed+nGrow;
void** pNewData = new void*[nNewSize];
if ( pData )
{
@@ -114,7 +114,7 @@ void SfxPtrArr::Append( void* aElem )
memmove( pNewData, pData, sizeof(void*)*nUsed );
delete [] pData;
}
- nUnused = sal::static_int_cast< BYTE >(nNewSize-nUsed);
+ nUnused = sal::static_int_cast< sal_uInt8 >(nNewSize-nUsed);
pData = pNewData;
}
@@ -126,11 +126,11 @@ void SfxPtrArr::Append( void* aElem )
// -----------------------------------------------------------------------
-USHORT SfxPtrArr::Remove( USHORT nPos, USHORT nLen )
+sal_uInt16 SfxPtrArr::Remove( sal_uInt16 nPos, sal_uInt16 nLen )
{
DBG_MEMTEST();
// nLen adjustieren, damit nicht ueber das Ende hinaus geloescht wird
- nLen = Min( (USHORT)(nUsed-nPos), nLen );
+ nLen = Min( (sal_uInt16)(nUsed-nPos), nLen );
// einfache Aufgaben erfordern einfache Loesungen!
if ( nLen == 0 )
@@ -150,8 +150,8 @@ USHORT SfxPtrArr::Remove( USHORT nPos, USHORT nLen )
if ( (nUnused+nLen) >= nGrow )
{
// auf die naechste Grow-Grenze aufgerundet verkleinern
- USHORT nNewUsed = nUsed-nLen;
- USHORT nNewSize = ((nNewUsed+nGrow-1)/nGrow) * nGrow;
+ sal_uInt16 nNewUsed = nUsed-nLen;
+ sal_uInt16 nNewSize = ((nNewUsed+nGrow-1)/nGrow) * nGrow;
DBG_ASSERT( nNewUsed <= nNewSize && nNewUsed+nGrow > nNewSize,
"shrink size computation failed" );
void** pNewData = new void*[nNewSize];
@@ -166,7 +166,7 @@ USHORT SfxPtrArr::Remove( USHORT nPos, USHORT nLen )
delete [] pData;
pData = pNewData;
nUsed = nNewUsed;
- nUnused = sal::static_int_cast< BYTE >(nNewSize - nNewUsed);
+ nUnused = sal::static_int_cast< sal_uInt8 >(nNewSize - nNewUsed);
return nLen;
}
@@ -174,71 +174,71 @@ USHORT SfxPtrArr::Remove( USHORT nPos, USHORT nLen )
if ( nUsed-nPos-nLen > 0 )
memmove( pData+nPos, pData+nPos+nLen, (nUsed-nPos-nLen)*sizeof(void*) );
nUsed = nUsed - nLen;
- nUnused = sal::static_int_cast< BYTE >(nUnused + nLen);
+ nUnused = sal::static_int_cast< sal_uInt8 >(nUnused + nLen);
return nLen;
}
// -----------------------------------------------------------------------
-BOOL SfxPtrArr::Remove( void* aElem )
+sal_Bool SfxPtrArr::Remove( void* aElem )
{
DBG_MEMTEST();
// einfache Aufgaben ...
if ( nUsed == 0 )
- return FALSE;
+ return sal_False;
// rueckwaerts, da meist der letzte zuerst wieder entfernt wird
void* *pIter = pData + nUsed - 1;
- for ( USHORT n = 0; n < nUsed; ++n, --pIter )
+ for ( sal_uInt16 n = 0; n < nUsed; ++n, --pIter )
if ( *pIter == aElem )
{
Remove(nUsed-n-1, 1);
- return TRUE;
+ return sal_True;
}
- return FALSE;
+ return sal_False;
}
// -----------------------------------------------------------------------
-BOOL SfxPtrArr::Replace( void* aOldElem, void* aNewElem )
+sal_Bool SfxPtrArr::Replace( void* aOldElem, void* aNewElem )
{
DBG_MEMTEST();
// einfache Aufgaben ...
if ( nUsed == 0 )
- return FALSE;
+ return sal_False;
// rueckwaerts, da meist der letzte zuerst wieder entfernt wird
void* *pIter = pData + nUsed - 1;
- for ( USHORT n = 0; n < nUsed; ++n, --pIter )
+ for ( sal_uInt16 n = 0; n < nUsed; ++n, --pIter )
if ( *pIter == aOldElem )
{
pData[nUsed-n-1] = aNewElem;
- return TRUE;
+ return sal_True;
}
- return FALSE;
+ return sal_False;
}
// -----------------------------------------------------------------------
-BOOL SfxPtrArr::Contains( const void* rItem ) const
+sal_Bool SfxPtrArr::Contains( const void* rItem ) const
{
DBG_MEMTEST();
if ( !nUsed )
- return FALSE;
+ return sal_False;
- for ( USHORT n = 0; n < nUsed; ++n )
+ for ( sal_uInt16 n = 0; n < nUsed; ++n )
{
void* p = GetObject(n);
if ( p == rItem )
- return TRUE;
+ return sal_True;
}
- return FALSE;
+ return sal_False;
}
// -----------------------------------------------------------------------
-void SfxPtrArr::Insert( USHORT nPos, void* rElem )
+void SfxPtrArr::Insert( sal_uInt16 nPos, void* rElem )
{
DBG_MEMTEST();
DBG_ASSERT( sal::static_int_cast< unsigned >(nUsed+1) < ( USHRT_MAX / sizeof(void*) ), "array too large" );
@@ -246,7 +246,7 @@ void SfxPtrArr::Insert( USHORT nPos, void* rElem )
if ( nUnused == 0 )
{
// auf die naechste Grow-Grenze aufgerundet vergroeszern
- USHORT nNewSize = nUsed+nGrow;
+ sal_uInt16 nNewSize = nUsed+nGrow;
void** pNewData = new void*[nNewSize];
if ( pData )
@@ -255,7 +255,7 @@ void SfxPtrArr::Insert( USHORT nPos, void* rElem )
memmove( pNewData, pData, sizeof(void*)*nUsed );
delete [] pData;
}
- nUnused = sal::static_int_cast< BYTE >(nNewSize-nUsed);
+ nUnused = sal::static_int_cast< sal_uInt8 >(nNewSize-nUsed);
pData = pNewData;
}
@@ -271,13 +271,13 @@ void SfxPtrArr::Insert( USHORT nPos, void* rElem )
// class ByteArr ---------------------------------------------------------
-ByteArr::ByteArr( BYTE nInitSize, BYTE nGrowSize ):
+ByteArr::ByteArr( sal_uInt8 nInitSize, sal_uInt8 nGrowSize ):
nUsed( 0 ),
nGrow( nGrowSize ? nGrowSize : 1 ),
nUnused( nInitSize )
{
DBG_MEMTEST();
- USHORT nMSCBug = nInitSize;
+ sal_uInt16 nMSCBug = nInitSize;
if ( nInitSize > 0 )
pData = new char[nMSCBug];
@@ -341,7 +341,7 @@ void ByteArr::Append( char aElem )
// musz das Array umkopiert werden?
if ( nUnused == 0 )
{
- USHORT nNewSize = (nUsed == 1) ? (nGrow==1 ? 2 : nGrow) : nUsed+nGrow;
+ sal_uInt16 nNewSize = (nUsed == 1) ? (nGrow==1 ? 2 : nGrow) : nUsed+nGrow;
char* pNewData = new char[nNewSize];
if ( pData )
{
@@ -349,7 +349,7 @@ void ByteArr::Append( char aElem )
memmove( pNewData, pData, sizeof(char)*nUsed );
delete [] pData;
}
- nUnused = sal::static_int_cast< BYTE >(nNewSize-nUsed);
+ nUnused = sal::static_int_cast< sal_uInt8 >(nNewSize-nUsed);
pData = pNewData;
}
@@ -361,11 +361,11 @@ void ByteArr::Append( char aElem )
// -----------------------------------------------------------------------
-USHORT ByteArr::Remove( USHORT nPos, USHORT nLen )
+sal_uInt16 ByteArr::Remove( sal_uInt16 nPos, sal_uInt16 nLen )
{
DBG_MEMTEST();
// nLen adjustieren, damit nicht ueber das Ende hinaus geloescht wird
- nLen = Min( (USHORT)(nUsed-nPos), nLen );
+ nLen = Min( (sal_uInt16)(nUsed-nPos), nLen );
// einfache Aufgaben erfordern einfache Loesungen!
if ( nLen == 0 )
@@ -385,8 +385,8 @@ USHORT ByteArr::Remove( USHORT nPos, USHORT nLen )
if ( (nUnused+nLen) >= nGrow )
{
// auf die naechste Grow-Grenze aufgerundet verkleinern
- USHORT nNewUsed = nUsed-nLen;
- USHORT nNewSize = ((nNewUsed+nGrow-1)/nGrow) * nGrow;
+ sal_uInt16 nNewUsed = nUsed-nLen;
+ sal_uInt16 nNewSize = ((nNewUsed+nGrow-1)/nGrow) * nGrow;
DBG_ASSERT( nNewUsed <= nNewSize && nNewUsed+nGrow > nNewSize,
"shrink size computation failed" );
char* pNewData = new char[nNewSize];
@@ -401,7 +401,7 @@ USHORT ByteArr::Remove( USHORT nPos, USHORT nLen )
delete [] pData;
pData = pNewData;
nUsed = nNewUsed;
- nUnused = sal::static_int_cast< BYTE >(nNewSize - nNewUsed);
+ nUnused = sal::static_int_cast< sal_uInt8 >(nNewSize - nNewUsed);
return nLen;
}
@@ -409,58 +409,58 @@ USHORT ByteArr::Remove( USHORT nPos, USHORT nLen )
if ( nUsed-nPos-nLen > 0 )
memmove( pData+nPos, pData+nPos+nLen, (nUsed-nPos-nLen)*sizeof(char) );
nUsed = nUsed - nLen;
- nUnused = sal::static_int_cast< BYTE >(nUnused + nLen);
+ nUnused = sal::static_int_cast< sal_uInt8 >(nUnused + nLen);
return nLen;
}
// -----------------------------------------------------------------------
-BOOL ByteArr::Remove( char aElem )
+sal_Bool ByteArr::Remove( char aElem )
{
DBG_MEMTEST();
// einfache Aufgaben ...
if ( nUsed == 0 )
- return FALSE;
+ return sal_False;
// rueckwaerts, da meist der letzte zuerst wieder entfernt wird
char *pIter = pData + nUsed - 1;
- for ( USHORT n = 0; n < nUsed; ++n, --pIter )
+ for ( sal_uInt16 n = 0; n < nUsed; ++n, --pIter )
if ( *pIter == aElem )
{
Remove(nUsed-n-1, 1);
- return TRUE;
+ return sal_True;
}
- return FALSE;
+ return sal_False;
}
// -----------------------------------------------------------------------
-BOOL ByteArr::Contains( const char rItem ) const
+sal_Bool ByteArr::Contains( const char rItem ) const
{
DBG_MEMTEST();
if ( !nUsed )
- return FALSE;
+ return sal_False;
- for ( USHORT n = 0; n < nUsed; ++n )
+ for ( sal_uInt16 n = 0; n < nUsed; ++n )
{
char p = GetObject(n);
if ( p == rItem )
- return TRUE;
+ return sal_True;
}
- return FALSE;
+ return sal_False;
}
// -----------------------------------------------------------------------
-void ByteArr::Insert( USHORT nPos, char rElem )
+void ByteArr::Insert( sal_uInt16 nPos, char rElem )
{
DBG_MEMTEST();
// musz das Array umkopiert werden?
if ( nUnused == 0 )
{
// auf die naechste Grow-Grenze aufgerundet vergroeszern
- USHORT nNewSize = nUsed+nGrow;
+ sal_uInt16 nNewSize = nUsed+nGrow;
char* pNewData = new char[nNewSize];
if ( pData )
@@ -469,7 +469,7 @@ void ByteArr::Insert( USHORT nPos, char rElem )
memmove( pNewData, pData, sizeof(char)*nUsed );
delete [] pData;
}
- nUnused = sal::static_int_cast< BYTE >(nNewSize-nUsed);
+ nUnused = sal::static_int_cast< sal_uInt8 >(nNewSize-nUsed);
pData = pNewData;
}
@@ -485,7 +485,7 @@ void ByteArr::Insert( USHORT nPos, char rElem )
// -----------------------------------------------------------------------
-char ByteArr::operator[]( USHORT nPos ) const
+char ByteArr::operator[]( sal_uInt16 nPos ) const
{
DBG_MEMTEST();
DBG_ASSERT( nPos < nUsed, "" );
@@ -494,7 +494,7 @@ char ByteArr::operator[]( USHORT nPos ) const
// -----------------------------------------------------------------------
-char& ByteArr::operator [] (USHORT nPos)
+char& ByteArr::operator [] (sal_uInt16 nPos)
{
DBG_MEMTEST();
DBG_ASSERT( nPos < nUsed, "" );
@@ -503,13 +503,13 @@ char& ByteArr::operator [] (USHORT nPos)
// class WordArr ---------------------------------------------------------
-WordArr::WordArr( BYTE nInitSize, BYTE nGrowSize ):
+WordArr::WordArr( sal_uInt8 nInitSize, sal_uInt8 nGrowSize ):
nUsed( 0 ),
nGrow( nGrowSize ? nGrowSize : 1 ),
nUnused( nInitSize )
{
DBG_MEMTEST();
- USHORT nMSCBug = nInitSize;
+ sal_uInt16 nMSCBug = nInitSize;
if ( nInitSize > 0 )
pData = new short[nMSCBug];
@@ -573,7 +573,7 @@ void WordArr::Append( short aElem )
// musz das Array umkopiert werden?
if ( nUnused == 0 )
{
- USHORT nNewSize = (nUsed == 1) ? (nGrow==1 ? 2 : nGrow) : nUsed+nGrow;
+ sal_uInt16 nNewSize = (nUsed == 1) ? (nGrow==1 ? 2 : nGrow) : nUsed+nGrow;
short* pNewData = new short[nNewSize];
if ( pData )
{
@@ -581,7 +581,7 @@ void WordArr::Append( short aElem )
memmove( pNewData, pData, sizeof(short)*nUsed );
delete [] pData;
}
- nUnused = sal::static_int_cast< BYTE >(nNewSize-nUsed);
+ nUnused = sal::static_int_cast< sal_uInt8 >(nNewSize-nUsed);
pData = pNewData;
}
@@ -593,11 +593,11 @@ void WordArr::Append( short aElem )
// -----------------------------------------------------------------------
-USHORT WordArr::Remove( USHORT nPos, USHORT nLen )
+sal_uInt16 WordArr::Remove( sal_uInt16 nPos, sal_uInt16 nLen )
{
DBG_MEMTEST();
// nLen adjustieren, damit nicht ueber das Ende hinaus geloescht wird
- nLen = Min( (USHORT)(nUsed-nPos), nLen );
+ nLen = Min( (sal_uInt16)(nUsed-nPos), nLen );
// einfache Aufgaben erfordern einfache Loesungen!
if ( nLen == 0 )
@@ -617,8 +617,8 @@ USHORT WordArr::Remove( USHORT nPos, USHORT nLen )
if ( (nUnused+nLen) >= nGrow )
{
// auf die naechste Grow-Grenze aufgerundet verkleinern
- USHORT nNewUsed = nUsed-nLen;
- USHORT nNewSize = ((nNewUsed+nGrow-1)/nGrow) * nGrow;
+ sal_uInt16 nNewUsed = nUsed-nLen;
+ sal_uInt16 nNewSize = ((nNewUsed+nGrow-1)/nGrow) * nGrow;
DBG_ASSERT( nNewUsed <= nNewSize && nNewUsed+nGrow > nNewSize,
"shrink size computation failed" );
short* pNewData = new short[nNewSize];
@@ -633,7 +633,7 @@ USHORT WordArr::Remove( USHORT nPos, USHORT nLen )
delete [] pData;
pData = pNewData;
nUsed = nNewUsed;
- nUnused = sal::static_int_cast< BYTE >(nNewSize - nNewUsed);
+ nUnused = sal::static_int_cast< sal_uInt8 >(nNewSize - nNewUsed);
return nLen;
}
@@ -641,58 +641,58 @@ USHORT WordArr::Remove( USHORT nPos, USHORT nLen )
if ( nUsed-nPos-nLen > 0 )
memmove( pData+nPos, pData+nPos+nLen, (nUsed-nPos-nLen)*sizeof(short) );
nUsed = nUsed - nLen;
- nUnused = sal::static_int_cast< BYTE >(nUnused + nLen);
+ nUnused = sal::static_int_cast< sal_uInt8 >(nUnused + nLen);
return nLen;
}
// -----------------------------------------------------------------------
-BOOL WordArr::Remove( short aElem )
+sal_Bool WordArr::Remove( short aElem )
{
DBG_MEMTEST();
// einfache Aufgaben ...
if ( nUsed == 0 )
- return FALSE;
+ return sal_False;
// rueckwaerts, da meist der letzte zuerst wieder entfernt wird
short *pIter = pData + nUsed - 1;
- for ( USHORT n = 0; n < nUsed; ++n, --pIter )
+ for ( sal_uInt16 n = 0; n < nUsed; ++n, --pIter )
if ( *pIter == aElem )
{
Remove(nUsed-n-1, 1);
- return TRUE;
+ return sal_True;
}
- return FALSE;
+ return sal_False;
}
// -----------------------------------------------------------------------
-BOOL WordArr::Contains( const short rItem ) const
+sal_Bool WordArr::Contains( const short rItem ) const
{
DBG_MEMTEST();
if ( !nUsed )
- return FALSE;
+ return sal_False;
- for ( USHORT n = 0; n < nUsed; ++n )
+ for ( sal_uInt16 n = 0; n < nUsed; ++n )
{
short p = GetObject(n);
if ( p == rItem )
- return TRUE;
+ return sal_True;
}
- return FALSE;
+ return sal_False;
}
// -----------------------------------------------------------------------
-void WordArr::Insert( USHORT nPos, short rElem )
+void WordArr::Insert( sal_uInt16 nPos, short rElem )
{
DBG_MEMTEST();
// musz das Array umkopiert werden?
if ( nUnused == 0 )
{
// auf die naechste Grow-Grenze aufgerundet vergroeszern
- USHORT nNewSize = nUsed+nGrow;
+ sal_uInt16 nNewSize = nUsed+nGrow;
short* pNewData = new short[nNewSize];
if ( pData )
@@ -701,7 +701,7 @@ void WordArr::Insert( USHORT nPos, short rElem )
memmove( pNewData, pData, sizeof(short)*nUsed );
delete [] pData;
}
- nUnused = sal::static_int_cast< BYTE >(nNewSize-nUsed);
+ nUnused = sal::static_int_cast< sal_uInt8 >(nNewSize-nUsed);
pData = pNewData;
}
@@ -717,7 +717,7 @@ void WordArr::Insert( USHORT nPos, short rElem )
// -----------------------------------------------------------------------
-short WordArr::operator[]( USHORT nPos ) const
+short WordArr::operator[]( sal_uInt16 nPos ) const
{
DBG_MEMTEST();
DBG_ASSERT( nPos < nUsed, "" );
@@ -726,7 +726,7 @@ short WordArr::operator[]( USHORT nPos ) const
// -----------------------------------------------------------------------
-short& WordArr::operator [] (USHORT nPos)
+short& WordArr::operator [] (sal_uInt16 nPos)
{
DBG_MEMTEST();
DBG_ASSERT( nPos < nUsed, "" );
diff --git a/sfx2/source/bastyp/misc.cxx b/sfx2/source/bastyp/misc.cxx
index 49938c729b36..ae3b0807bbe4 100644
--- a/sfx2/source/bastyp/misc.cxx
+++ b/sfx2/source/bastyp/misc.cxx
@@ -46,7 +46,7 @@ String SearchAndReplace( const String &rSource,
const String &rReplacement )
{
String aTarget( rSource );
- USHORT nPos = rSource.Search( rToReplace );
+ sal_uInt16 nPos = rSource.Search( rToReplace );
if ( nPos != STRING_NOTFOUND )
{
aTarget.Erase( nPos, rToReplace.Len() );
diff --git a/sfx2/source/bastyp/sfxresid.cxx b/sfx2/source/bastyp/sfxresid.cxx
index cf1cd983f76e..0ed0aab649cf 100644
--- a/sfx2/source/bastyp/sfxresid.cxx
+++ b/sfx2/source/bastyp/sfxresid.cxx
@@ -39,7 +39,7 @@
static ResMgr* pMgr=NULL;
-SfxResId::SfxResId( USHORT nId ) :
+SfxResId::SfxResId( sal_uInt16 nId ) :
ResId( nId, *GetResMgr() )
{
@@ -51,7 +51,7 @@ SfxResId::SfxResId( USHORT nId ) :
//
//============================================================================
-SfxSimpleResId::SfxSimpleResId(USHORT nID):
+SfxSimpleResId::SfxSimpleResId(sal_uInt16 nID):
m_sText( SFX_APP()->GetSimpleResManager()->ReadString(nID) )
{}
diff --git a/sfx2/source/control/minfitem.cxx b/sfx2/source/control/minfitem.cxx
index b0cdd58d2645..c5e46620a908 100644
--- a/sfx2/source/control/minfitem.cxx
+++ b/sfx2/source/control/minfitem.cxx
@@ -39,7 +39,7 @@ TYPEINIT1(SfxMacroInfoItem, SfxPoolItem);
// -----------------------------------------------------------------------
SfxMacroInfoItem::SfxMacroInfoItem(
- USHORT nWhichId, // Slot-ID
+ sal_uInt16 nWhichId, // Slot-ID
const BasicManager* pMgr,
const String &rLibName,
const String &rModuleName,
diff --git a/sfx2/source/control/msgpool.cxx b/sfx2/source/control/msgpool.cxx
index 10359ba20f73..0d10d13a3790 100644
--- a/sfx2/source/control/msgpool.cxx
+++ b/sfx2/source/control/msgpool.cxx
@@ -53,20 +53,20 @@ struct SfxSIDRegistration_Impl
{
String _aGroup;
String _aName;
- USHORT _nSID;
+ sal_uInt16 _nSID;
};
struct SfxSlotType_Impl
{
- USHORT nId;
+ sal_uInt16 nId;
TypeId nType;
- SfxSlotType_Impl( USHORT nTheId, TypeId nTheType ):
+ SfxSlotType_Impl( sal_uInt16 nTheId, TypeId nTheType ):
nId(nTheId), nType(nTheType)
{}
};
-DECL_2BYTEARRAY(SfxSlotGroupArr_Impl, USHORT, 6, 4)
+DECL_2BYTEARRAY(SfxSlotGroupArr_Impl, sal_uInt16, 6, 4)
DECL_PTRARRAY(SfxInterfaceArr_Impl, SfxInterface*, 6, 3)
DECL_PTRARRAY(SfxSlotTypeArr_Impl, SfxSlotType_Impl*, 8, 8)
@@ -99,7 +99,7 @@ SfxSlotPool::~SfxSlotPool()
delete _pGroups;
if ( _pTypes )
{
- for ( USHORT n =_pTypes->Count(); n--; )
+ for ( sal_uInt16 n =_pTypes->Count(); n--; )
delete _pTypes->GetObject(n);
delete _pTypes;
}
@@ -132,14 +132,14 @@ void SfxSlotPool::RegisterInterface( SfxInterface& rInterface )
{
// Die Groups im parent Slotpool sind auch hier bekannt
SfxSlotGroupArr_Impl& rGroups = *_pParentPool->_pGroups;
- for ( USHORT n=0; n<rGroups.Count(); n++ )
+ for ( sal_uInt16 n=0; n<rGroups.Count(); n++ )
_pGroups->Append( rGroups[n] );
}
}
if ( !_pTypes )
_pTypes = new SfxSlotTypeArr_Impl;
- for ( USHORT nFunc = 0; nFunc < rInterface.Count(); ++nFunc )
+ for ( sal_uInt16 nFunc = 0; nFunc < rInterface.Count(); ++nFunc )
{
SfxSlot *pDef = rInterface[nFunc];
if ( pDef->GetGroupId() && /* pDef->GetGroupId() != GID_INTERN && */
@@ -154,7 +154,7 @@ void SfxSlotPool::RegisterInterface( SfxInterface& rInterface )
const TypeId &rTypeId = pDef->GetType()->Type();
if ( /*rTypeId != TYPE(SfxVoidItem) &&*/ rTypeId != 0 )
{
- USHORT nPos;
+ sal_uInt16 nPos;
for ( nPos = 0; nPos < _pTypes->Count(); ++nPos )
{
if ( _pTypes->GetObject(nPos)->nId == pDef->GetSlotId() )
@@ -175,12 +175,12 @@ void SfxSlotPool::RegisterInterface( SfxInterface& rInterface )
//====================================================================
-TypeId SfxSlotPool::GetSlotType( USHORT nId ) const
+TypeId SfxSlotPool::GetSlotType( sal_uInt16 nId ) const
{
const SfxSlot* pSlot = (const_cast <SfxSlotPool*> (this))->GetSlot( nId );
return pSlot ? pSlot->GetType()->Type() : 0;
/*
- for ( USHORT nPos = 0; nPos < _pTypes->Count(); ++nPos )
+ for ( sal_uInt16 nPos = 0; nPos < _pTypes->Count(); ++nPos )
{
if ( _pTypes->GetObject(nPos)->nId == nId )
return _pTypes->GetObject(nPos)->nType;
@@ -205,13 +205,13 @@ void SfxSlotPool::ReleaseInterface( SfxInterface& rInterface )
// get the first SfxMessage for a special Id (e.g. for getting check-mode)
-const SfxSlot* SfxSlotPool::GetSlot( USHORT nId )
+const SfxSlot* SfxSlotPool::GetSlot( sal_uInt16 nId )
{
DBG_MEMTEST();
DBG_ASSERT( _pInterfaces != 0, "no Interfaces registered" );
// Zun"achst die eigenen Interfaces absuchen
- for ( USHORT nInterf = 0; nInterf < _pInterfaces->Count(); ++nInterf )
+ for ( sal_uInt16 nInterf = 0; nInterf < _pInterfaces->Count(); ++nInterf )
{
const SfxSlot *pDef = _pInterfaces->GetObject(nInterf)->GetSlot(nId);
if ( pDef )
@@ -226,7 +226,7 @@ const SfxSlot* SfxSlotPool::GetSlot( USHORT nId )
// skips to the next group
-String SfxSlotPool::SeekGroup( USHORT nNo )
+String SfxSlotPool::SeekGroup( sal_uInt16 nNo )
{
DBG_MEMTEST();
DBG_ASSERT( _pInterfaces != 0, "no Interfaces registered" );
@@ -238,7 +238,7 @@ String SfxSlotPool::SeekGroup( USHORT nNo )
if ( _pParentPool )
{
// Meistens stimmt die Reihenfolge der Ids "uberein
- USHORT nParentCount = _pParentPool->_pGroups->Count();
+ sal_uInt16 nParentCount = _pParentPool->_pGroups->Count();
if ( nNo < nParentCount && (*_pGroups)[nNo] == (*_pParentPool->_pGroups)[nNo] )
_pParentPool->_nCurGroup = nNo;
else
@@ -246,7 +246,7 @@ String SfxSlotPool::SeekGroup( USHORT nNo )
// Ansonsten mu\s gesucht werden
// Wenn die Gruppe im parent pool nicht gefunden wird, wird
// _nCurGroup au\serhalb des g"ultigen Bereiches gesetzt
- USHORT i;
+ sal_uInt16 i;
for ( i=1; i<nParentCount; i++ )
if ( (*_pGroups)[nNo] == (*_pParentPool->_pGroups)[i] )
break;
@@ -271,7 +271,7 @@ String SfxSlotPool::SeekGroup( USHORT nNo )
//--------------------------------------------------------------------
-USHORT SfxSlotPool::GetGroupCount()
+sal_uInt16 SfxSlotPool::GetGroupCount()
{
return _pGroups->Count();
}
@@ -281,13 +281,13 @@ USHORT SfxSlotPool::GetGroupCount()
// internal search loop
-const SfxSlot* SfxSlotPool::SeekSlot( USHORT nStartInterface )
+const SfxSlot* SfxSlotPool::SeekSlot( sal_uInt16 nStartInterface )
{
DBG_MEMTEST();
DBG_ASSERT( _pInterfaces != 0, "no Interfaces registered" );
// Die Numerierung der interfaces startet beim parent pool
- USHORT nFirstInterface = _pParentPool ? _pParentPool->_pInterfaces->Count() : 0;
+ sal_uInt16 nFirstInterface = _pParentPool ? _pParentPool->_pInterfaces->Count() : 0;
// sind wir am Ende des Parent-Pools angekommen?
if ( nStartInterface < nFirstInterface &&
@@ -303,7 +303,7 @@ const SfxSlot* SfxSlotPool::SeekSlot( USHORT nStartInterface )
}
// find the first func-def with the current group id
- USHORT nCount = _pInterfaces->Count() + nFirstInterface;
+ sal_uInt16 nCount = _pInterfaces->Count() + nFirstInterface;
for ( _nCurInterface = nStartInterface;
_nCurInterface < nCount;
++_nCurInterface )
@@ -332,7 +332,7 @@ const SfxSlot* SfxSlotPool::NextSlot()
DBG_ASSERT( _pInterfaces != 0, "no Interfaces registered" );
// Die Numerierung der interfaces startet beim parent pool
- USHORT nFirstInterface = _pParentPool ? _pParentPool->_pInterfaces->Count() : 0;
+ sal_uInt16 nFirstInterface = _pParentPool ? _pParentPool->_pInterfaces->Count() : 0;
if ( _nCurInterface < nFirstInterface && _nCurGroup >= _pParentPool->_pGroups->Count() )
_nCurInterface = nFirstInterface;
@@ -349,7 +349,7 @@ const SfxSlot* SfxSlotPool::NextSlot()
return SeekSlot( nFirstInterface );
}
- USHORT nInterface = _nCurInterface - nFirstInterface;
+ sal_uInt16 nInterface = _nCurInterface - nFirstInterface;
// possibly we are already at the end
if ( nInterface >= _pInterfaces->Count() )
return 0;
@@ -387,17 +387,17 @@ SfxInterface* SfxSlotPool::FirstInterface()
SfxInterface* SfxSlotPool::NextInterface()
{
_nCurInterface++;
- USHORT nFirstInterface = _pParentPool ? _pParentPool->_pInterfaces->Count() : 0;
+ sal_uInt16 nFirstInterface = _pParentPool ? _pParentPool->_pInterfaces->Count() : 0;
if ( _nCurInterface < nFirstInterface )
return (*_pParentPool->_pInterfaces)[_nCurInterface];
- USHORT nInterface = _nCurInterface - nFirstInterface;
+ sal_uInt16 nInterface = _nCurInterface - nFirstInterface;
return nInterface < _pInterfaces->Count() ? (*_pInterfaces)[nInterface] : 0;
}
const SfxSlot* SfxSlotPool::GetUnoSlot( const String& rName )
{
const SfxSlot *pSlot = NULL;
- for ( USHORT nInterface=0; nInterface<_pInterfaces->Count(); nInterface++ )
+ for ( sal_uInt16 nInterface=0; nInterface<_pInterfaces->Count(); nInterface++ )
{
pSlot = (*_pInterfaces)[nInterface]->GetSlot( rName );
if ( pSlot )
diff --git a/sfx2/source/control/querystatus.cxx b/sfx2/source/control/querystatus.cxx
index bee4a5c87675..9fb17332c27d 100644
--- a/sfx2/source/control/querystatus.cxx
+++ b/sfx2/source/control/querystatus.cxx
@@ -59,7 +59,7 @@ class SfxQueryStatus_Impl : public ::com::sun::star::frame::XStatusListener ,
public:
SFX_DECL_XINTERFACE_XTYPEPROVIDER
- SfxQueryStatus_Impl( const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XDispatchProvider >& rDispatchProvider, USHORT nSlotId, const rtl::OUString& aCommand );
+ SfxQueryStatus_Impl( const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XDispatchProvider >& rDispatchProvider, sal_uInt16 nSlotId, const rtl::OUString& aCommand );
virtual ~SfxQueryStatus_Impl();
// Query method
@@ -79,7 +79,7 @@ class SfxQueryStatus_Impl : public ::com::sun::star::frame::XStatusListener ,
sal_Bool m_bQueryInProgress;
SfxItemState m_eState;
SfxPoolItem* m_pItem;
- USHORT m_nSlotID;
+ sal_uInt16 m_nSlotID;
osl::Condition m_aCondition;
::com::sun::star::util::URL m_aCommand;
com::sun::star::uno::Reference< com::sun::star::frame::XDispatch > m_xDispatch;
@@ -88,7 +88,7 @@ class SfxQueryStatus_Impl : public ::com::sun::star::frame::XStatusListener ,
SFX_IMPL_XINTERFACE_2( SfxQueryStatus_Impl, OWeakObject, ::com::sun::star::frame::XStatusListener, ::com::sun::star::lang::XEventListener )
SFX_IMPL_XTYPEPROVIDER_2( SfxQueryStatus_Impl, ::com::sun::star::frame::XStatusListener, ::com::sun::star::lang::XEventListener )
-SfxQueryStatus_Impl::SfxQueryStatus_Impl( const Reference< XDispatchProvider >& rDispatchProvider, USHORT nSlotId, const OUString& rCommand ) :
+SfxQueryStatus_Impl::SfxQueryStatus_Impl( const Reference< XDispatchProvider >& rDispatchProvider, sal_uInt16 nSlotId, const OUString& rCommand ) :
cppu::OWeakObject(),
m_bQueryInProgress( sal_False ),
m_eState( SFX_ITEM_DISABLED ),
@@ -222,7 +222,7 @@ SfxItemState SfxQueryStatus_Impl::QueryState( SfxPoolItem*& rpPoolItem )
//*************************************************************************
-SfxQueryStatus::SfxQueryStatus( const Reference< XDispatchProvider >& rDispatchProvider, USHORT nSlotId, const OUString& rCommand )
+SfxQueryStatus::SfxQueryStatus( const Reference< XDispatchProvider >& rDispatchProvider, sal_uInt16 nSlotId, const OUString& rCommand )
{
m_pSfxQueryStatusImpl = new SfxQueryStatus_Impl( rDispatchProvider, nSlotId, rCommand );
m_xStatusListener = Reference< XStatusListener >(
diff --git a/sfx2/source/control/sfxstatuslistener.cxx b/sfx2/source/control/sfxstatuslistener.cxx
index c2cf5f164e7c..96f305f58389 100644
--- a/sfx2/source/control/sfxstatuslistener.cxx
+++ b/sfx2/source/control/sfxstatuslistener.cxx
@@ -61,7 +61,7 @@ using namespace ::com::sun::star::util;
SFX_IMPL_XINTERFACE_3( SfxStatusListener, OWeakObject, ::com::sun::star::lang::XComponent, ::com::sun::star::frame::XStatusListener, ::com::sun::star::lang::XEventListener )
SFX_IMPL_XTYPEPROVIDER_3( SfxStatusListener, ::com::sun::star::lang::XComponent, ::com::sun::star::frame::XStatusListener, ::com::sun::star::lang::XEventListener )
-SfxStatusListener::SfxStatusListener( const Reference< XDispatchProvider >& rDispatchProvider, USHORT nSlotId, const OUString& rCommand ) :
+SfxStatusListener::SfxStatusListener( const Reference< XDispatchProvider >& rDispatchProvider, sal_uInt16 nSlotId, const OUString& rCommand ) :
cppu::OWeakObject(),
m_nSlotID( nSlotId ),
m_xDispatchProvider( rDispatchProvider )
@@ -79,7 +79,7 @@ SfxStatusListener::~SfxStatusListener()
}
// old sfx controller item C++ API
-void SfxStatusListener::StateChanged( USHORT, SfxItemState, const SfxPoolItem* )
+void SfxStatusListener::StateChanged( sal_uInt16, SfxItemState, const SfxPoolItem* )
{
// must be implemented by sub class
}
@@ -100,7 +100,7 @@ void SfxStatusListener::Bind()
}
}
-void SfxStatusListener::Bind( USHORT nSlotId, const rtl::OUString& rNewCommand )
+void SfxStatusListener::Bind( sal_uInt16 nSlotId, const rtl::OUString& rNewCommand )
{
// first remove old listener, if we have a dispatch object
Reference< XStatusListener > aStatusListener( static_cast< OWeakObject* >( this ), UNO_QUERY );
diff --git a/sfx2/source/dialog/about.cxx b/sfx2/source/dialog/about.cxx
index ea7b0a2bb0bd..dbe88ab598ce 100644
--- a/sfx2/source/dialog/about.cxx
+++ b/sfx2/source/dialog/about.cxx
@@ -166,7 +166,7 @@ AboutDialog::AboutDialog( Window* pParent, const ResId& rId, const String& rVerS
nOff ( 0 ),
m_nDeltaWidth ( 0 ),
m_nPendingScrolls( 0 ),
- bNormal ( TRUE )
+ bNormal ( sal_True )
{
rtl::OUString sProduct;
utl::ConfigManager::GetDirectConfigProperty(utl::ConfigManager::PRODUCTNAME) >>= sProduct;
@@ -176,7 +176,7 @@ AboutDialog::AboutDialog( Window* pParent, const ResId& rId, const String& rVerS
// Transparenter Font
Font aFont = GetFont();
- aFont.SetTransparent( TRUE );
+ aFont.SetTransparent( sal_True );
SetFont( aFont );
// if necessary more info
@@ -192,12 +192,12 @@ AboutDialog::AboutDialog( Window* pParent, const ResId& rId, const String& rVerS
Accelerator *pAccel = 0, *pPrevAccel = 0, *pFirstAccel = 0;
aAccelStr.ToUpperAscii();
- for ( USHORT i = 0; i < aAccelStr.Len(); ++i )
+ for ( sal_uInt16 i = 0; i < aAccelStr.Len(); ++i )
{
pPrevAccel = pAccel;
pAccel = new Accelerator;
aAccelList.Insert( pAccel, LIST_APPEND );
- USHORT nKey = aAccelStr.GetChar(i) - 'A' + KEY_A;
+ sal_uInt16 nKey = aAccelStr.GetChar(i) - 'A' + KEY_A;
pAccel->InsertItem( 1, KeyCode( nKey, KEY_MOD1 ) );
if ( i > 0 )
pPrevAccel->SetAccel( 1, pAccel );
@@ -214,7 +214,7 @@ AboutDialog::AboutDialog( Window* pParent, const ResId& rId, const String& rVerS
Wallpaper aWall( aWhiteCol );
SetBackground( aWall );
Font aNewFont( aCopyrightText.GetFont() );
- aNewFont.SetTransparent( TRUE );
+ aNewFont.SetTransparent( sal_True );
aVersionText.SetFont( aNewFont );
aCopyrightText.SetFont( aNewFont );
@@ -330,7 +330,7 @@ IMPL_LINK( AboutDialog, AccelSelectHdl, Accelerator *, pAccelerator )
nOff = GetOutputSizePixel().Height();
MapMode aMapMode( MAP_PIXEL );
SetMapMode( aMapMode );
- bNormal = FALSE;
+ bNormal = sal_False;
// start scroll Timer
aTimer.SetTimeout( SCROLL_TIMER );
@@ -340,12 +340,12 @@ IMPL_LINK( AboutDialog, AccelSelectHdl, Accelerator *, pAccelerator )
// -----------------------------------------------------------------------
-BOOL AboutDialog::Close()
+sal_Bool AboutDialog::Close()
{
// stop Timer and finish the dialog
aTimer.Stop();
EndDialog( RET_OK );
- return( FALSE );
+ return( sal_False );
}
// -----------------------------------------------------------------------
@@ -417,7 +417,7 @@ void AboutDialog::Paint( const Rectangle& rRect )
// close dialog if the whole text has been scrolled
if ( nY <= 0 )
{
- bNormal = TRUE;
+ bNormal = sal_True;
Close();
}
}
diff --git a/sfx2/source/dialog/filedlghelper.cxx b/sfx2/source/dialog/filedlghelper.cxx
index b740453cf5ff..0f3b35648061 100644
--- a/sfx2/source/dialog/filedlghelper.cxx
+++ b/sfx2/source/dialog/filedlghelper.cxx
@@ -1433,8 +1433,8 @@ void lcl_saveLastURLs(SvStringsDtor*& rpURLLi
::comphelper::SequenceAsVector< ::rtl::OUString >& lLastURLs )
{
lLastURLs.clear();
- USHORT c = rpURLList->Count();
- USHORT i = 0;
+ sal_uInt16 c = rpURLList->Count();
+ sal_uInt16 i = 0;
for (i=0; i<c; ++i)
lLastURLs.push_back(*(rpURLList->GetObject(i)));
}
@@ -1522,15 +1522,15 @@ ErrCode FileDialogHelper_Impl::execute( SvStringsDtor*& rpURLList,
// check password checkbox if the document had password before
if( mbHasPassword )
{
- SFX_ITEMSET_ARG( rpSet, pPassItem, SfxBoolItem, SID_PASSWORDINTERACTION, FALSE );
+ SFX_ITEMSET_ARG( rpSet, pPassItem, SfxBoolItem, SID_PASSWORDINTERACTION, sal_False );
mbPwdCheckBoxState = ( pPassItem != NULL && pPassItem->GetValue() );
// in case the document has password to modify, the dialog should be shown
- SFX_ITEMSET_ARG( rpSet, pPassToModifyItem, SfxUnoAnyItem, SID_MODIFYPASSWORDINFO, FALSE );
+ SFX_ITEMSET_ARG( rpSet, pPassToModifyItem, SfxUnoAnyItem, SID_MODIFYPASSWORDINFO, sal_False );
mbPwdCheckBoxState |= ( pPassToModifyItem && pPassToModifyItem->GetValue().hasValue() );
}
- SFX_ITEMSET_ARG( rpSet, pSelectItem, SfxBoolItem, SID_SELECTION, FALSE );
+ SFX_ITEMSET_ARG( rpSet, pSelectItem, SfxBoolItem, SID_SELECTION, sal_False );
if ( pSelectItem )
mbSelection = pSelectItem->GetValue();
else
@@ -1957,7 +1957,7 @@ void FileDialogHelper_Impl::addGraphicFilter()
// create the list of filters
mpGraphicFilter = new GraphicFilter;
- USHORT i, j, nCount = mpGraphicFilter->GetImportFormatCount();
+ sal_uInt16 i, j, nCount = mpGraphicFilter->GetImportFormatCount();
// compute the extension string for all known import filters
String aExtensions;
@@ -1966,7 +1966,7 @@ void FileDialogHelper_Impl::addGraphicFilter()
{
j = 0;
String sWildcard;
- while( TRUE )
+ while( sal_True )
{
sWildcard = mpGraphicFilter->GetImportWildcard( i, j++ );
if ( !sWildcard.Len() )
@@ -2006,7 +2006,7 @@ void FileDialogHelper_Impl::addGraphicFilter()
String aExt;
j = 0;
String sWildcard;
- while( TRUE )
+ while( sal_True )
{
sWildcard = mpGraphicFilter->GetImportWildcard( i, j++ );
if ( !sWildcard.Len() )
diff --git a/sfx2/source/dialog/filedlgimpl.hxx b/sfx2/source/dialog/filedlgimpl.hxx
index 91190b575e1c..6c559139ddd2 100644
--- a/sfx2/source/dialog/filedlgimpl.hxx
+++ b/sfx2/source/dialog/filedlgimpl.hxx
@@ -84,7 +84,7 @@ namespace sfx2
SfxFilterFlags m_nMustFlags;
SfxFilterFlags m_nDontFlags;
- ULONG mnPostUserEventId;
+ sal_uIntPtr mnPostUserEventId;
ErrCode mnError;
diff --git a/sfx2/source/dialog/passwd.cxx b/sfx2/source/dialog/passwd.cxx
index 455479b9d125..d9c1ea80636d 100644
--- a/sfx2/source/dialog/passwd.cxx
+++ b/sfx2/source/dialog/passwd.cxx
@@ -190,7 +190,7 @@ SfxPasswordDialog::SfxPasswordDialog( Window* pParent, const String* pGroupText
// -----------------------------------------------------------------------
-void SfxPasswordDialog::SetMinLen( USHORT nLen )
+void SfxPasswordDialog::SetMinLen( sal_uInt16 nLen )
{
mnMinLen = nLen;
EditModifyHdl( NULL );
@@ -198,7 +198,7 @@ void SfxPasswordDialog::SetMinLen( USHORT nLen )
// -----------------------------------------------------------------------
-void SfxPasswordDialog::SetMaxLen( USHORT nLen )
+void SfxPasswordDialog::SetMaxLen( sal_uInt16 nLen )
{
maPasswordED.SetMaxTextLen( nLen );
maConfirmED.SetMaxTextLen( nLen );
diff --git a/sfx2/source/dialog/styfitem.cxx b/sfx2/source/dialog/styfitem.cxx
index a33677c6b2ae..ba6fac0fdee8 100644
--- a/sfx2/source/dialog/styfitem.cxx
+++ b/sfx2/source/dialog/styfitem.cxx
@@ -54,17 +54,17 @@ SfxStyleFamilyItem::SfxStyleFamilyItem( const ResId &rResId ) :
Resource( rResId.SetRT( RSC_SFX_STYLE_FAMILY_ITEM ) )
{
- ULONG nMask = ReadLongRes();
+ sal_uIntPtr nMask = ReadLongRes();
if(nMask & RSC_SFX_STYLE_ITEM_LIST)
{
- ULONG nCount = ReadLongRes();
- for( ULONG i = 0; i < nCount; i++ )
+ sal_uIntPtr nCount = ReadLongRes();
+ for( sal_uIntPtr i = 0; i < nCount; i++ )
{
SfxFilterTupel *pTupel = new SfxFilterTupel;
pTupel->aName = ReadStringRes();
long lFlags = ReadLongRes();
- pTupel->nFlags = (USHORT)lFlags;
+ pTupel->nFlags = (sal_uInt16)lFlags;
aFilterList.Insert(pTupel, LIST_APPEND);
}
}
@@ -83,7 +83,7 @@ SfxStyleFamilyItem::SfxStyleFamilyItem( const ResId &rResId ) :
}
if(nMask & RSC_SFX_STYLE_ITEM_STYLEFAMILY)
{
- nFamily = (USHORT)ReadLongRes();
+ nFamily = (sal_uInt16)ReadLongRes();
}
else
nFamily = SFX_STYLE_FAMILY_PARA;
@@ -116,11 +116,11 @@ SfxStyleFamilyItem::~SfxStyleFamilyItem()
SfxStyleFamilies::SfxStyleFamilies( const ResId& rResId ) :
- Resource( rResId.SetRT( RSC_SFX_STYLE_FAMILIES ).SetAutoRelease( FALSE ) ),
+ Resource( rResId.SetRT( RSC_SFX_STYLE_FAMILIES ).SetAutoRelease( sal_False ) ),
aEntryList( 4, 1 )
{
- ULONG nCount = ReadLongRes();
- for( ULONG i = 0; i < nCount; i++ )
+ sal_uIntPtr nCount = ReadLongRes();
+ for( sal_uIntPtr i = 0; i < nCount; i++ )
{
const ResId aResId((RSHEADER_TYPE *)GetClassRes(), *rResId.GetResMgr());
SfxStyleFamilyItem *pItem = new SfxStyleFamilyItem(aResId);
diff --git a/sfx2/source/dialog/tplpitem.cxx b/sfx2/source/dialog/tplpitem.cxx
index 566c379df508..a159f95ffd6d 100644
--- a/sfx2/source/dialog/tplpitem.cxx
+++ b/sfx2/source/dialog/tplpitem.cxx
@@ -47,7 +47,7 @@ SfxTemplateItem::SfxTemplateItem() :
SfxTemplateItem::SfxTemplateItem
(
- USHORT nWhichId, // Slot-ID
+ sal_uInt16 nWhichId, // Slot-ID
const String& rStyle, // Name des aktuellen Styles
USHORT nValue // Flags f"ur das Filtern bei automatischer Anzeige
) : SfxFlagItem( nWhichId, nValue ),
@@ -84,7 +84,7 @@ SfxPoolItem* SfxTemplateItem::Clone( SfxItemPool *) const
}
//-------------------------------------------------------------------------
-sal_Bool SfxTemplateItem::QueryValue( com::sun::star::uno::Any& rVal, BYTE /*nMemberId*/ ) const
+sal_Bool SfxTemplateItem::QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 /*nMemberId*/ ) const
{
::com::sun::star::frame::status::Template aTemplate;
@@ -96,13 +96,13 @@ sal_Bool SfxTemplateItem::QueryValue( com::sun::star::uno::Any& rVal, BYTE /*nMe
}
//-------------------------------------------------------------------------
-sal_Bool SfxTemplateItem::PutValue( const com::sun::star::uno::Any& rVal, BYTE /*nMemberId*/ )
+sal_Bool SfxTemplateItem::PutValue( const com::sun::star::uno::Any& rVal, sal_uInt8 /*nMemberId*/ )
{
::com::sun::star::frame::status::Template aTemplate;
if ( rVal >>= aTemplate )
{
- SetValue( sal::static_int_cast< USHORT >( aTemplate.Value ) );
+ SetValue( sal::static_int_cast< sal_uInt16 >( aTemplate.Value ) );
aStyle = aTemplate.StyleName;
return sal_True;
}
@@ -112,9 +112,9 @@ sal_Bool SfxTemplateItem::PutValue( const com::sun::star::uno::Any& rVal, BYTE /
//-------------------------------------------------------------------------
-BYTE SfxTemplateItem::GetFlagCount() const
+sal_uInt8 SfxTemplateItem::GetFlagCount() const
{
- return sizeof(USHORT) * 8;
+ return sizeof(sal_uInt16) * 8;
}
diff --git a/sfx2/source/doc/docfac.cxx b/sfx2/source/doc/docfac.cxx
index ff0a15e20088..1ef90b67b173 100644
--- a/sfx2/source/doc/docfac.cxx
+++ b/sfx2/source/doc/docfac.cxx
@@ -381,7 +381,7 @@ const SfxObjectFactory* SfxObjectFactory::GetFactory( const String& rFactoryURL
const SfxFilter* SfxObjectFactory::GetTemplateFilter() const
{
- USHORT nVersion=0;
+ sal_uInt16 nVersion=0;
SfxFilterMatcher aMatcher ( String::CreateFromAscii( pShortName ) );
SfxFilterMatcherIter aIter( &aMatcher );
const SfxFilter *pFilter = 0;
@@ -391,7 +391,7 @@ const SfxFilter* SfxObjectFactory::GetTemplateFilter() const
if( pTemp->IsOwnFormat() && pTemp->IsOwnTemplateFormat() && ( pTemp->GetVersion() > nVersion ) )
{
pFilter = pTemp;
- nVersion = (USHORT) pTemp->GetVersion();
+ nVersion = (sal_uInt16) pTemp->GetVersion();
}
pTemp = aIter.Next();
@@ -476,7 +476,7 @@ sal_uInt16 SfxObjectFactory::GetViewNo_Impl( const sal_uInt16 i_nViewId, const s
SfxViewFactory* SfxObjectFactory::GetViewFactoryByViewName( const String& i_rViewName ) const
{
- for ( USHORT nViewNo = 0;
+ for ( sal_uInt16 nViewNo = 0;
nViewNo < GetViewFactoryCount();
++nViewNo
)
diff --git a/sfx2/source/doc/docinsert.cxx b/sfx2/source/doc/docinsert.cxx
index 360854dc3dbf..e03f18691a09 100644
--- a/sfx2/source/doc/docinsert.cxx
+++ b/sfx2/source/doc/docinsert.cxx
@@ -111,9 +111,9 @@ SfxMedium* DocumentInserter::CreateMedium()
DBG_ASSERT( m_pURLList->Count() == 1, "DocumentInserter::CreateMedium(): invalid URL list count" );
String sURL = *( m_pURLList->GetObject(0) );
pMedium = new SfxMedium(
- sURL, SFX_STREAM_READONLY, FALSE,
+ sURL, SFX_STREAM_READONLY, sal_False,
SFX_APP()->GetFilterMatcher().GetFilter4FilterName( m_sFilter ), m_pItemSet );
- pMedium->UseInteractionHandler( TRUE );
+ pMedium->UseInteractionHandler( sal_True );
SfxFilterMatcher* pMatcher = NULL;
if ( m_sDocFactory.Len() )
pMatcher = new SfxFilterMatcher( m_sDocFactory );
@@ -121,7 +121,7 @@ SfxMedium* DocumentInserter::CreateMedium()
pMatcher = new SfxFilterMatcher();
const SfxFilter* pFilter = NULL;
- sal_uInt32 nError = pMatcher->DetectFilter( *pMedium, &pFilter, FALSE );
+ sal_uInt32 nError = pMatcher->DetectFilter( *pMedium, &pFilter, sal_False );
if ( nError == ERRCODE_NONE && pFilter )
pMedium->SetFilter( pFilter );
else
@@ -145,16 +145,16 @@ SfxMediumList* DocumentInserter::CreateMediumList()
sal_Int32 nCount = m_pURLList->Count();
for ( ; i < nCount; ++i )
{
- String sURL = *( m_pURLList->GetObject( static_cast< USHORT >(i) ) );
+ String sURL = *( m_pURLList->GetObject( static_cast< sal_uInt16 >(i) ) );
SfxMedium* pMedium = new SfxMedium(
- sURL, SFX_STREAM_READONLY, FALSE,
+ sURL, SFX_STREAM_READONLY, sal_False,
SFX_APP()->GetFilterMatcher().GetFilter4FilterName( m_sFilter ), m_pItemSet );
- pMedium->UseInteractionHandler( TRUE );
+ pMedium->UseInteractionHandler( sal_True );
SfxFilterMatcher aMatcher( m_sDocFactory );
const SfxFilter* pFilter = NULL;
- sal_uInt32 nError = aMatcher.DetectFilter( *pMedium, &pFilter, FALSE );
+ sal_uInt32 nError = aMatcher.DetectFilter( *pMedium, &pFilter, sal_False );
if ( nError == ERRCODE_NONE && pFilter )
pMedium->SetFilter( pFilter );
else
@@ -180,7 +180,7 @@ void impl_FillURLList( sfx2::FileDialogHelper* _pFileDlg, SvStringsDtor*& _rpURL
{
_rpURLList = new SvStringsDtor;
- for ( USHORT i = 0; i < aPathSeq.getLength(); ++i )
+ for ( sal_uInt16 i = 0; i < aPathSeq.getLength(); ++i )
{
INetURLObject aPathObj( aPathSeq[i] );
String* pURL = new String( aPathObj.GetMainURL( INetURLObject::NO_DECODE ) );
diff --git a/sfx2/source/doc/doctdlg.cxx b/sfx2/source/doc/doctdlg.cxx
index e6726e97e96d..7a3c4a66f443 100644
--- a/sfx2/source/doc/doctdlg.cxx
+++ b/sfx2/source/doc/doctdlg.cxx
@@ -112,8 +112,8 @@ void SfxDocumentTemplateDlg::Init()
if(!pTemplates->IsConstructed())
pTemplates->Construct();
- const USHORT nCount = pTemplates->GetRegionCount();
- for(USHORT i = 0; i < nCount; ++i)
+ const sal_uInt16 nCount = pTemplates->GetRegionCount();
+ for(sal_uInt16 i = 0; i < nCount; ++i)
aRegionLb.InsertEntry(pTemplates->GetFullRegionName(i));
if(!nCount)
aRegionLb.InsertEntry(String(SfxResId(STR_STANDARD)));
@@ -144,10 +144,10 @@ IMPL_LINK( SfxDocumentTemplateDlg, OrganizeHdl, Button *, pButton )
if(RET_OK == nRet)
{
// View aktualisieren
- aRegionLb.SetUpdateMode( FALSE );
+ aRegionLb.SetUpdateMode( sal_False );
aRegionLb.Clear();
Init();
- aRegionLb.SetUpdateMode( TRUE );
+ aRegionLb.SetUpdateMode( sal_True );
aRegionLb.Invalidate();
aRegionLb.Update();
aCancelBt.SetText(String(SfxResId(STR_CLOSE)));
@@ -177,14 +177,14 @@ IMPL_LINK( SfxDocumentTemplateDlg, OkHdl, Control *, pControl )
IMPL_LINK( SfxDocumentTemplateDlg, RegionSelect, ListBox *, pBox )
{
- const USHORT nRegion = pBox->GetSelectEntryPos();
- const USHORT nCount = pTemplates->GetCount(nRegion);
- aTemplateLb.SetUpdateMode(FALSE);
+ const sal_uInt16 nRegion = pBox->GetSelectEntryPos();
+ const sal_uInt16 nCount = pTemplates->GetCount(nRegion);
+ aTemplateLb.SetUpdateMode(sal_False);
aTemplateLb.Clear();
- for(USHORT i = 0; i < nCount; ++i)
+ for(sal_uInt16 i = 0; i < nCount; ++i)
aTemplateLb.InsertEntry(pTemplates->GetName(nRegion, i));
aTemplateLb.SelectEntryPos(0);
- aTemplateLb.SetUpdateMode(TRUE);
+ aTemplateLb.SetUpdateMode(sal_True);
aTemplateLb.Invalidate();
aTemplateLb.Update();
return 0;
diff --git a/sfx2/source/doc/doctempl.cxx b/sfx2/source/doc/doctempl.cxx
index 4fccc95058b7..a45c9daff789 100644
--- a/sfx2/source/doc/doctempl.cxx
+++ b/sfx2/source/doc/doctempl.cxx
@@ -906,8 +906,8 @@ sal_Bool SfxDocumentTemplates::CopyOrMove
Aktion konnte nicht ausgef2uhrt werden
[Querverweise]
- <SfxDocumentTemplates::Move(sal_uInt16,USHORT,sal_uInt16,USHORT)>
- <SfxDocumentTemplates::Copy(sal_uInt16,USHORT,sal_uInt16,USHORT)>
+ <SfxDocumentTemplates::Move(sal_uInt16,sal_uInt16,sal_uInt16,sal_uInt16)>
+ <SfxDocumentTemplates::Copy(sal_uInt16,sal_uInt16,sal_uInt16,sal_uInt16)>
*/
{
@@ -1032,7 +1032,7 @@ sal_Bool SfxDocumentTemplates::Move
[Querverweise]
- <SfxDocumentTemplates::CopyOrMove(sal_uInt16,USHORT,sal_uInt16,USHORT,sal_Bool)>
+ <SfxDocumentTemplates::CopyOrMove(sal_uInt16,sal_uInt16,sal_uInt16,sal_uInt16,sal_Bool)>
*/
{
DocTemplLocker_Impl aLocker( *pImp );
@@ -1067,7 +1067,7 @@ sal_Bool SfxDocumentTemplates::Copy
[Querverweise]
- <SfxDocumentTemplates::CopyOrMove(sal_uInt16,USHORT,sal_uInt16,USHORT,sal_Bool)>
+ <SfxDocumentTemplates::CopyOrMove(sal_uInt16,sal_uInt16,sal_uInt16,sal_uInt16,sal_Bool)>
*/
{
@@ -1105,7 +1105,7 @@ sal_Bool SfxDocumentTemplates::CopyTo
[Querverweise]
- <SfxDocumentTemplates::CopyFrom(sal_uInt16,USHORT,String&)>
+ <SfxDocumentTemplates::CopyFrom(sal_uInt16,sal_uInt16,String&)>
*/
{
@@ -1184,7 +1184,7 @@ sal_Bool SfxDocumentTemplates::CopyFrom
[Querverweise]
- <SfxDocumentTemplates::CopyTo(sal_uInt16,USHORT,const String&)>
+ <SfxDocumentTemplates::CopyTo(sal_uInt16,sal_uInt16,const String&)>
*/
{
diff --git a/sfx2/source/doc/objembed.cxx b/sfx2/source/doc/objembed.cxx
index 1c2105c210b9..a83335ea9fcd 100644
--- a/sfx2/source/doc/objembed.cxx
+++ b/sfx2/source/doc/objembed.cxx
@@ -101,7 +101,7 @@ void SfxObjectShell::OnDocumentPrinterChanged( Printer* /*pNewPrinter*/ )
}
// -----------------------------------------------------------------------
-Rectangle SfxObjectShell::GetVisArea( USHORT nAspect ) const
+Rectangle SfxObjectShell::GetVisArea( sal_uInt16 nAspect ) const
{
if( nAspect == ASPECT_CONTENT )
return pImp->m_aVisArea;
@@ -131,7 +131,7 @@ void SfxObjectShell::SetVisArea( const Rectangle & rVisArea )
if ( GetCreateMode() == SFX_CREATE_MODE_EMBEDDED )
{
if ( IsEnableSetModified() )
- SetModified( TRUE );
+ SetModified( sal_True );
SFX_APP()->NotifyEvent(SfxEventHint( SFX_EVENT_VISAREACHANGED, GlobalEventConfig::GetEventName(STR_EVENT_VISAREACHANGED), this));
@@ -184,7 +184,7 @@ void SfxObjectShell::SetVisAreaSize( const Size & rVisSize )
}
// -----------------------------------------------------------------------
-ULONG SfxObjectShell::GetMiscStatus() const
+sal_uIntPtr SfxObjectShell::GetMiscStatus() const
{
return 0;
}
@@ -213,7 +213,7 @@ void SfxObjectShell::FillTransferableObjectDescriptor( TransferableObjectDescrip
rDesc.maSize = OutputDevice::LogicToLogic( GetVisArea().GetSize(), GetMapUnit(), MAP_100TH_MM );
rDesc.maDragStartPos = Point();
rDesc.maDisplayName = String();
- rDesc.mbCanLink = FALSE;
+ rDesc.mbCanLink = sal_False;
}
// -----------------------------------------------------------------------
@@ -221,7 +221,7 @@ void SfxObjectShell::DoDraw( OutputDevice* pDev,
const Point & rObjPos,
const Size & rSize,
const JobSetup & rSetup,
- USHORT nAspect )
+ sal_uInt16 nAspect )
{
MapMode aMod = pDev->GetMapMode();
Size aSize = GetVisArea( nAspect ).GetSize();
@@ -245,7 +245,7 @@ void SfxObjectShell::DoDraw_Impl( OutputDevice* pDev,
const Fraction & rScaleX,
const Fraction & rScaleY,
const JobSetup & rSetup,
- USHORT nAspect )
+ sal_uInt16 nAspect )
{
Rectangle aVisArea = GetVisArea( nAspect );
// MapUnit des Ziels
diff --git a/sfx2/source/doc/objitem.cxx b/sfx2/source/doc/objitem.cxx
index 2980d984fd78..01fb87f29eac 100644
--- a/sfx2/source/doc/objitem.cxx
+++ b/sfx2/source/doc/objitem.cxx
@@ -64,7 +64,7 @@ SfxPoolItem* SfxObjectShellItem::Clone( SfxItemPool *) const
//--------------------------------------------------------------------
-sal_Bool SfxObjectShellItem::QueryValue( com::sun::star::uno::Any& rVal, BYTE /*nMemberId*/ ) const
+sal_Bool SfxObjectShellItem::QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 /*nMemberId*/ ) const
{
if ( pObjSh )
{
@@ -76,12 +76,12 @@ sal_Bool SfxObjectShellItem::QueryValue( com::sun::star::uno::Any& rVal, BYTE /*
{
rVal <<= ::com::sun::star::uno::Reference< ::com::sun::star::frame::XModel >();
}
- return TRUE;
+ return sal_True;
}
//--------------------------------------------------------------------
-sal_Bool SfxObjectShellItem::PutValue( const com::sun::star::uno::Any& rVal, BYTE /*nMemberId*/ )
+sal_Bool SfxObjectShellItem::PutValue( const com::sun::star::uno::Any& rVal, sal_uInt8 /*nMemberId*/ )
{
// This item MUST have a model. Please don't change this, there are UNO-based
// implementations which need it!!
@@ -100,21 +100,21 @@ sal_Bool SfxObjectShellItem::PutValue( const com::sun::star::uno::Any& rVal, BYT
if ( nHandle )
{
pObjSh = reinterpret_cast< SfxObjectShell* >(sal::static_int_cast<sal_IntPtr>( nHandle ));
- return TRUE;
+ return sal_True;
}
}
}
pObjSh = 0;
- return TRUE;
+ return sal_True;
}
- return FALSE;
+ return sal_False;
}
//=========================================================================
-SfxObjectItem::SfxObjectItem( USHORT nWhichId, SfxShell *pSh )
+SfxObjectItem::SfxObjectItem( sal_uInt16 nWhichId, SfxShell *pSh )
: SfxPoolItem( nWhichId ),
_pSh( pSh )
{}
diff --git a/sfx2/source/doc/objxtor.cxx b/sfx2/source/doc/objxtor.cxx
index 693911f0404c..148123d5c31a 100644
--- a/sfx2/source/doc/objxtor.cxx
+++ b/sfx2/source/doc/objxtor.cxx
@@ -174,8 +174,8 @@ void SAL_CALL SfxModelListener_Impl::disposing( const com::sun::star::lang::Even
if ( mpDoc->Get_Impl()->bHiddenLockedByAPI )
{
- mpDoc->Get_Impl()->bHiddenLockedByAPI = FALSE;
- mpDoc->OwnerLock(FALSE);
+ mpDoc->Get_Impl()->bHiddenLockedByAPI = sal_False;
+ mpDoc->OwnerLock(sal_False);
}
else if ( !mpDoc->Get_Impl()->bClosing )
// GCC stuerzt ab, wenn schon im dtor, also vorher Flag abfragen
@@ -820,7 +820,7 @@ void SfxObjectShell::InitBasicManager_Impl()
changed to return the Basic manager currently under construction, when
called repeatedly.
- The variable pImp->bBasicInitialized will be set to TRUE after
+ The variable pImp->bBasicInitialized will be set to sal_True after
construction now, to ensure that the recursive call of the function
lcl_getBasicManagerForDocument() will be routed into this function too.
@@ -831,7 +831,7 @@ void SfxObjectShell::InitBasicManager_Impl()
DBG_ASSERT( !pImp->bBasicInitialized && !pImp->pBasicManager->isValid(), "Lokaler BasicManager bereits vorhanden");
pImp->pBasicManager->reset( BasicManagerRepository::getDocumentBasicManager( GetModel() ) );
DBG_ASSERT( pImp->pBasicManager->isValid(), "SfxObjectShell::InitBasicManager_Impl: did not get a BasicManager!" );
- pImp->bBasicInitialized = TRUE;
+ pImp->bBasicInitialized = sal_True;
}
//--------------------------------------------------------------------
@@ -962,7 +962,7 @@ String SfxObjectShell::GetServiceNameFromFactory( const String& rFact )
String aPrefix = String::CreateFromAscii( "private:factory/" );
if ( aPrefix.Len() == aFact.Match( aPrefix ) )
aFact.Erase( 0, aPrefix.Len() );
- USHORT nPos = aFact.Search( '?' );
+ sal_uInt16 nPos = aFact.Search( '?' );
String aParam;
if ( nPos != STRING_NOTFOUND )
{
@@ -1055,8 +1055,8 @@ SfxObjectShell* SfxObjectShell::CreateAndLoadObject( const SfxItemSet& rSet, Sfx
{
uno::Sequence < beans::PropertyValue > aProps;
TransformItems( SID_OPENDOC, rSet, aProps );
- SFX_ITEMSET_ARG(&rSet, pFileNameItem, SfxStringItem, SID_FILE_NAME, FALSE);
- SFX_ITEMSET_ARG(&rSet, pTargetItem, SfxStringItem, SID_TARGETNAME, FALSE);
+ SFX_ITEMSET_ARG(&rSet, pFileNameItem, SfxStringItem, SID_FILE_NAME, sal_False);
+ SFX_ITEMSET_ARG(&rSet, pTargetItem, SfxStringItem, SID_TARGETNAME, sal_False);
::rtl::OUString aURL;
::rtl::OUString aTarget = rtl::OUString::createFromAscii("_blank");
if ( pFileNameItem )
diff --git a/sfx2/source/doc/plugin.cxx b/sfx2/source/doc/plugin.cxx
index 9ff8c73acbf6..8c731845554f 100644
--- a/sfx2/source/doc/plugin.cxx
+++ b/sfx2/source/doc/plugin.cxx
@@ -105,7 +105,7 @@ throw( uno::RuntimeException )
{
uno::Reference< plugin::XPluginManager > xPMgr( mxFact->createInstance( ::rtl::OUString::createFromAscii("com.sun.star.plugin.PluginManager") ), uno::UNO_QUERY );
if (!xPMgr.is() )
- return FALSE;
+ return sal_False;
if ( SvtMiscOptions().IsPluginsEnabled() )
{
@@ -115,10 +115,10 @@ throw( uno::RuntimeException )
pWin->SetBackground();
pWin->Show();
- ULONG nCount = maCmdList.Count();
+ sal_uIntPtr nCount = maCmdList.Count();
uno::Sequence < ::rtl::OUString > aCmds( nCount ), aArgs( nCount );
::rtl::OUString *pCmds = aCmds.getArray(), *pArgs = aArgs.getArray();
- for( ULONG i = 0; i < nCount; i++ )
+ for( sal_uIntPtr i = 0; i < nCount; i++ )
{
SvCommand & rCmd = maCmdList.GetObject( i );
pCmds[i] = rCmd.GetCommand();
@@ -136,7 +136,7 @@ throw( uno::RuntimeException )
{
pWin->xWindow = xWindow;
pWin->Resize();
- xWindow->setVisible( TRUE );
+ xWindow->setVisible( sal_True );
}
try
@@ -165,10 +165,10 @@ throw( uno::RuntimeException )
// we must destroy the plugin before the parent is destroyed
xWindow->addEventListener( this );
xFrame->setComponent( xWindow, uno::Reference < frame::XController >() );
- return mxPlugin.is() ? TRUE : FALSE;
+ return mxPlugin.is() ? sal_True : sal_False;
}
- return FALSE;
+ return sal_False;
}
void SAL_CALL PluginObject::cancel() throw( com::sun::star::uno::RuntimeException )
diff --git a/sfx2/source/doc/printhelper.cxx b/sfx2/source/doc/printhelper.cxx
index 2cd195976832..3d3462eea389 100755
--- a/sfx2/source/doc/printhelper.cxx
+++ b/sfx2/source/doc/printhelper.cxx
@@ -423,8 +423,8 @@ void SfxPrintHelper::impl_setPrinter(const uno::Sequence< beans::PropertyValue >
rtl::OUString aTmp;
if ( ( rProp.Value >>= aTmp ) == sal_False )
throw ::com::sun::star::lang::IllegalArgumentException();
- USHORT nCount = pPrinter->GetPaperBinCount();
- for (USHORT nBin=0; nBin<nCount; nBin++)
+ sal_uInt16 nCount = pPrinter->GetPaperBinCount();
+ for (sal_uInt16 nBin=0; nBin<nCount; nBin++)
{
::rtl::OUString aName( pPrinter->GetPaperBinName(nBin) );
if ( aName == aTmp )
diff --git a/sfx2/source/explorer/nochaos.cxx b/sfx2/source/explorer/nochaos.cxx
index 63c165bea7eb..32d1cf2cf6fd 100644
--- a/sfx2/source/explorer/nochaos.cxx
+++ b/sfx2/source/explorer/nochaos.cxx
@@ -72,7 +72,7 @@ public:
class CntItemPool: public SfxItemPool
{
static CntItemPool* _pThePool;
- USHORT _nRefs;
+ sal_uInt16 _nRefs;
protected:
CntItemPool();
@@ -80,7 +80,7 @@ protected:
public:
static CntItemPool* Acquire();
- static USHORT Release();
+ static sal_uInt16 Release();
};
//----------------------------------------------------------------------------
@@ -95,7 +95,7 @@ SfxItemPool* NoChaos::GetItemPool()
//----------------------------------------------------------------------------
// static
-USHORT NoChaos::ReleaseItemPool()
+sal_uInt16 NoChaos::ReleaseItemPool()
{
// Release CHAOS item pool.
return CntItemPool::Release();
diff --git a/sfx2/source/inc/appbas.hxx b/sfx2/source/inc/appbas.hxx
index 8b10fcb843de..05c182419514 100644
--- a/sfx2/source/inc/appbas.hxx
+++ b/sfx2/source/inc/appbas.hxx
@@ -36,7 +36,7 @@ class SbxObject;
//=========================================================================
SbxVariable* MakeVariable( StarBASIC *pBas, SbxObject *pObject,
- const char *pName, ULONG nSID, SbxDataType eType=SbxOBJECT,
+ const char *pName, sal_uIntPtr nSID, SbxDataType eType=SbxOBJECT,
SbxClassType = SbxCLASS_PROPERTY );
diff --git a/sfx2/source/inc/helper.hxx b/sfx2/source/inc/helper.hxx
index 45aed74b154a..6e0061a69cf2 100644
--- a/sfx2/source/inc/helper.hxx
+++ b/sfx2/source/inc/helper.hxx
@@ -66,7 +66,7 @@ public:
static sal_Bool MakeFolder( const String& rFolder );
static ErrCode QueryDiskSpace( const String& rPath, sal_Int64& rFreeBytes );
- static ULONG GetSize( const String& rContent );
+ static sal_uIntPtr GetSize( const String& rContent );
// please don't use this!
static sal_Bool Exists( const String& rContent );
diff --git a/sfx2/source/inc/mnucfga.hxx b/sfx2/source/inc/mnucfga.hxx
index bbc3c1cd63ac..609661e638e9 100644
--- a/sfx2/source/inc/mnucfga.hxx
+++ b/sfx2/source/inc/mnucfga.hxx
@@ -38,7 +38,7 @@ class SfxMenuCfgItemArr;
struct SfxMenuCfgItem
{
- USHORT nId; // id of the binding or 0 if none
+ sal_uInt16 nId; // id of the binding or 0 if none
String aTitle; // title of the item
String aHelpText; // Hilfetext
String aCommand;
diff --git a/sfx2/source/inc/nochaos.hxx b/sfx2/source/inc/nochaos.hxx
index 4b5d7fb1f40e..daa06f8e4371 100644
--- a/sfx2/source/inc/nochaos.hxx
+++ b/sfx2/source/inc/nochaos.hxx
@@ -33,7 +33,7 @@ class NoChaos
{
public:
static SfxItemPool* GetItemPool();
- static USHORT ReleaseItemPool();
+ static sal_uInt16 ReleaseItemPool();
};
#endif
diff --git a/sfx2/source/inc/objmnctl.hxx b/sfx2/source/inc/objmnctl.hxx
index e58c6cd5592d..cac1da05fd48 100644
--- a/sfx2/source/inc/objmnctl.hxx
+++ b/sfx2/source/inc/objmnctl.hxx
@@ -44,10 +44,10 @@ class SfxObjectVerbsControl: public SfxMenuControl
private:
void FillMenu();
DECL_LINK( MenuSelect, Menu * );
- virtual void StateChanged( USHORT, SfxItemState, const SfxPoolItem* pState );
+ virtual void StateChanged( sal_uInt16, SfxItemState, const SfxPoolItem* pState );
public:
- SfxObjectVerbsControl(USHORT, Menu&, SfxBindings&);
+ SfxObjectVerbsControl(sal_uInt16, Menu&, SfxBindings&);
~SfxObjectVerbsControl();
virtual PopupMenu* GetPopup() const;
SFX_DECL_MENU_CONTROL();
diff --git a/sfx2/source/inc/sfxpicklist.hxx b/sfx2/source/inc/sfxpicklist.hxx
index 8b5069f20296..830ba2e3b810 100644
--- a/sfx2/source/inc/sfxpicklist.hxx
+++ b/sfx2/source/inc/sfxpicklist.hxx
@@ -63,7 +63,7 @@ class SfxPickList : public SfxListener
static osl::Mutex* GetOrCreateMutex();
- void CreatePicklistMenuTitle( Menu* pMenu, USHORT nItemId, const String& aURL, sal_uInt32 nNo );
+ void CreatePicklistMenuTitle( Menu* pMenu, sal_uInt16 nItemId, const String& aURL, sal_uInt32 nNo );
PickListEntry* GetPickListEntry( sal_uInt32 nIndex );
void CreatePickListEntries();
void RemovePickListEntries();
@@ -76,7 +76,7 @@ class SfxPickList : public SfxListener
sal_uInt32 GetAllowedMenuSize() { return m_nAllowedMenuSize; }
sal_uInt32 GetNumOfEntries() const { return m_aPicklistVector.size(); }
void CreateMenuEntries( Menu* pMenu );
- void ExecuteMenuEntry( USHORT nId );
+ void ExecuteMenuEntry( sal_uInt16 nId );
void ExecuteEntry( sal_uInt32 nIndex );
String GetMenuEntryTitle( sal_uInt32 nIndex );
diff --git a/sfx2/source/inc/slotserv.hxx b/sfx2/source/inc/slotserv.hxx
index 9b0a8e94733c..afef5e926f5f 100644
--- a/sfx2/source/inc/slotserv.hxx
+++ b/sfx2/source/inc/slotserv.hxx
@@ -35,14 +35,14 @@ class SfxSlotServer
{
private:
const SfxSlot* _pSlot;
- USHORT _nShellLevel;
+ sal_uInt16 _nShellLevel;
public:
- SfxSlotServer( const SfxSlot &rSlot, USHORT nShell );
+ SfxSlotServer( const SfxSlot &rSlot, sal_uInt16 nShell );
SfxSlotServer();
- USHORT GetShellLevel() const;
- void SetShellLevel(USHORT nLevel) { _nShellLevel = nLevel; }
+ sal_uInt16 GetShellLevel() const;
+ void SetShellLevel(sal_uInt16 nLevel) { _nShellLevel = nLevel; }
void SetSlot(const SfxSlot* pSlot) {
_pSlot = pSlot;
}
@@ -52,7 +52,7 @@ public:
//--------------------------------------------------------------------
-inline SfxSlotServer::SfxSlotServer( const SfxSlot &rSlot, USHORT nShell ):
+inline SfxSlotServer::SfxSlotServer( const SfxSlot &rSlot, sal_uInt16 nShell ):
_pSlot( &rSlot),
_nShellLevel( nShell )
{
@@ -68,7 +68,7 @@ inline SfxSlotServer::SfxSlotServer():
//--------------------------------------------------------------------
-inline USHORT SfxSlotServer::GetShellLevel() const
+inline sal_uInt16 SfxSlotServer::GetShellLevel() const
{
return _nShellLevel;
}
diff --git a/sfx2/source/inc/tplcitem.hxx b/sfx2/source/inc/tplcitem.hxx
index f97d7f89868c..af2ede51701d 100644
--- a/sfx2/source/inc/tplcitem.hxx
+++ b/sfx2/source/inc/tplcitem.hxx
@@ -34,17 +34,17 @@ class SfxCommonTemplateDialog_Impl;
class SfxTemplateControllerItem: public SfxControllerItem {
SfxCommonTemplateDialog_Impl &rTemplateDlg;
- BYTE nWaterCanState;
+ sal_uInt8 nWaterCanState;
long nUserEventId;
DECL_STATIC_LINK(SfxTemplateControllerItem, SetWaterCanStateHdl_Impl,
SfxTemplateControllerItem*);
protected:
- virtual void StateChanged( USHORT, SfxItemState, const SfxPoolItem* pState );
+ virtual void StateChanged( sal_uInt16, SfxItemState, const SfxPoolItem* pState );
public:
- SfxTemplateControllerItem( USHORT nId, SfxCommonTemplateDialog_Impl &rDlg, SfxBindings &);
+ SfxTemplateControllerItem( sal_uInt16 nId, SfxCommonTemplateDialog_Impl &rDlg, SfxBindings &);
~SfxTemplateControllerItem();
};
diff --git a/sfx2/source/menu/thessubmenu.cxx b/sfx2/source/menu/thessubmenu.cxx
index d82c0a6dbdf3..501d3e35f326 100755
--- a/sfx2/source/menu/thessubmenu.cxx
+++ b/sfx2/source/menu/thessubmenu.cxx
@@ -66,7 +66,7 @@ SFX_IMPL_MENU_CONTROL(SfxThesSubMenuControl, SfxStringItem);
Ctor; setzt Select-Handler am Menu und traegt Menu
in seinen Parent ein.
*/
-SfxThesSubMenuControl::SfxThesSubMenuControl( USHORT nSlotId, Menu &rMenu, SfxBindings &rBindings )
+SfxThesSubMenuControl::SfxThesSubMenuControl( sal_uInt16 nSlotId, Menu &rMenu, SfxBindings &rBindings )
: SfxMenuControl( nSlotId, rBindings ),
pMenu(new PopupMenu),
rParent(rMenu)
@@ -74,7 +74,7 @@ SfxThesSubMenuControl::SfxThesSubMenuControl( USHORT nSlotId, Menu &rMenu, SfxBi
rMenu.SetPopupMenu(nSlotId, pMenu);
pMenu->SetSelectHdl(LINK(this, SfxThesSubMenuControl, MenuSelect));
pMenu->Clear();
- rParent.EnableItem( GetId(), FALSE );
+ rParent.EnableItem( GetId(), sal_False );
}
@@ -90,7 +90,7 @@ SfxThesSubMenuControl::~SfxThesSubMenuControl()
Menueeintrag im Parentmenu disabled, andernfalls wird er enabled.
*/
void SfxThesSubMenuControl::StateChanged(
- USHORT /*nSID*/,
+ sal_uInt16 /*nSID*/,
SfxItemState eState,
const SfxPoolItem* /*pState*/ )
{
@@ -104,7 +104,7 @@ void SfxThesSubMenuControl::StateChanged(
*/
IMPL_LINK_INLINE_START( SfxThesSubMenuControl, MenuSelect, Menu *, pSelMenu )
{
- const USHORT nSlotId = pSelMenu->GetCurItemId();
+ const sal_uInt16 nSlotId = pSelMenu->GetCurItemId();
if( nSlotId )
GetBindings().Execute(nSlotId);
return 1;
diff --git a/sfx2/source/menu/thessubmenu.hxx b/sfx2/source/menu/thessubmenu.hxx
index 0b86a534de52..394c22b6e497 100644
--- a/sfx2/source/menu/thessubmenu.hxx
+++ b/sfx2/source/menu/thessubmenu.hxx
@@ -52,11 +52,11 @@ class SfxThesSubMenuControl : public SfxMenuControl
Menu& rParent;
private:
- virtual void StateChanged( USHORT, SfxItemState, const SfxPoolItem* pState );
+ virtual void StateChanged( sal_uInt16, SfxItemState, const SfxPoolItem* pState );
DECL_LINK( MenuSelect, Menu * );
public:
- SfxThesSubMenuControl(USHORT, Menu&, SfxBindings&);
+ SfxThesSubMenuControl(sal_uInt16, Menu&, SfxBindings&);
~SfxThesSubMenuControl();
virtual PopupMenu* GetPopup() const;
diff --git a/sfx2/source/view/frmload.cxx b/sfx2/source/view/frmload.cxx
index a4707f03d364..1a578643e443 100644
--- a/sfx2/source/view/frmload.cxx
+++ b/sfx2/source/view/frmload.cxx
@@ -252,13 +252,13 @@ namespace
}
// --------------------------------------------------------------------------------------------------------------------
-sal_Bool SfxFrameLoader_Impl::impl_createNewDocWithSlotParam( const USHORT _nSlotID, const Reference< XFrame >& i_rxFrame,
+sal_Bool SfxFrameLoader_Impl::impl_createNewDocWithSlotParam( const sal_uInt16 _nSlotID, const Reference< XFrame >& i_rxFrame,
const bool i_bHidden )
{
SfxRequest aRequest( _nSlotID, SFX_CALLMODE_SYNCHRON, SFX_APP()->GetPool() );
aRequest.AppendItem( SfxUnoFrameItem( SID_FILLFRAME, i_rxFrame ) );
if ( i_bHidden )
- aRequest.AppendItem( SfxBoolItem( SID_HIDDEN, TRUE ) );
+ aRequest.AppendItem( SfxBoolItem( SID_HIDDEN, sal_True ) );
return lcl_getDispatchResult( SFX_APP()->ExecuteSlot( aRequest ) );
}
@@ -277,8 +277,8 @@ void SfxFrameLoader_Impl::impl_lockHiddenDocument( SfxObjectShell& i_rDocument,
// To prevent it from being closed when the loader returns, increase its OwnerLock
// (the OwnerLock is normally increased by every frame in which the document is displayed, and by this loader)
i_rDocument.RestoreNoDelete();
- i_rDocument.OwnerLock( TRUE );
- i_rDocument.Get_Impl()->bHiddenLockedByAPI = TRUE;
+ i_rDocument.OwnerLock( sal_True );
+ i_rDocument.Get_Impl()->bHiddenLockedByAPI = sal_True;
}
// --------------------------------------------------------------------------------------------------------------------
@@ -333,7 +333,7 @@ void SfxFrameLoader_Impl::impl_determineFilter( ::comphelper::NamedValueCollecti
// --------------------------------------------------------------------------------------------------------------------
SfxObjectShellLock SfxFrameLoader_Impl::impl_findObjectShell( const Reference< XModel2 >& i_rxDocument ) const
{
- for ( SfxObjectShell* pDoc = SfxObjectShell::GetFirst( NULL, FALSE ); pDoc; pDoc = SfxObjectShell::GetNext( *pDoc, NULL, FALSE ) )
+ for ( SfxObjectShell* pDoc = SfxObjectShell::GetFirst( NULL, sal_False ); pDoc; pDoc = SfxObjectShell::GetNext( *pDoc, NULL, sal_False ) )
{
if ( i_rxDocument == pDoc->GetModel() )
{
@@ -391,7 +391,7 @@ bool SfxFrameLoader_Impl::impl_determineTemplateDocument( ::comphelper::NamedVal
}
// --------------------------------------------------------------------------------------------------------------------
-USHORT SfxFrameLoader_Impl::impl_findSlotParam( const ::rtl::OUString& i_rFactoryURL ) const
+sal_uInt16 SfxFrameLoader_Impl::impl_findSlotParam( const ::rtl::OUString& i_rFactoryURL ) const
{
::rtl::OUString sSlotParam;
const sal_Int32 nParamPos = i_rFactoryURL.indexOf( '?' );
@@ -404,7 +404,7 @@ USHORT SfxFrameLoader_Impl::impl_findSlotParam( const ::rtl::OUString& i_rFactor
}
if ( sSlotParam.getLength() )
- return USHORT( sSlotParam.toInt32() );
+ return sal_uInt16( sSlotParam.toInt32() );
return 0;
}
@@ -571,7 +571,7 @@ sal_Bool SAL_CALL SfxFrameLoader_Impl::load( const Sequence< PropertyValue >& rA
{
const ::rtl::OUString sFactory = sURL.copy( sizeof( "private:factory/" ) -1 );
// special handling for some weird factory URLs a la private:factory/swriter?slot=21053
- const USHORT nSlotParam = impl_findSlotParam( sFactory );
+ const sal_uInt16 nSlotParam = impl_findSlotParam( sFactory );
if ( nSlotParam != 0 )
{
return impl_createNewDocWithSlotParam( nSlotParam, _rTargetFrame, aDescriptor.getOrDefault( "Hidden", false ) );
diff --git a/sfx2/source/view/userinputinterception.cxx b/sfx2/source/view/userinputinterception.cxx
index ad910a944e0f..97c9e7926e39 100644
--- a/sfx2/source/view/userinputinterception.cxx
+++ b/sfx2/source/view/userinputinterception.cxx
@@ -184,7 +184,7 @@ namespace sfx2
{
Reference < XInterface > xHoldAlive( m_pData->m_rControllerImpl );
- USHORT nType = _rEvent.GetType();
+ sal_uInt16 nType = _rEvent.GetType();
bool bHandled = false;
switch ( nType )
diff --git a/sfx2/source/view/viewfac.cxx b/sfx2/source/view/viewfac.cxx
index 3eed678420dd..1b48d716ff79 100644
--- a/sfx2/source/view/viewfac.cxx
+++ b/sfx2/source/view/viewfac.cxx
@@ -71,7 +71,7 @@ String SfxViewFactory::GetAPIViewName() const
// CTOR / DTOR -----------------------------------------------------------
SfxViewFactory::SfxViewFactory( SfxViewCtor fnC, SfxViewInit fnI,
- USHORT nOrdinal, const sal_Char* asciiViewName ):
+ sal_uInt16 nOrdinal, const sal_Char* asciiViewName ):
fnCreate(fnC),
fnInit(fnI),
nOrd(nOrdinal),
diff --git a/sfx2/source/view/viewimp.hxx b/sfx2/source/view/viewimp.hxx
index 0826e78870bb..83c916d3071e 100644
--- a/sfx2/source/view/viewimp.hxx
+++ b/sfx2/source/view/viewimp.hxx
@@ -61,7 +61,7 @@ struct SfxViewShell_Impl
SvBorder aBorder;
Size aOptimalSize;
Size aMargin;
- USHORT m_nPrinterLocks;
+ sal_uInt16 m_nPrinterLocks;
bool m_bCanPrint;
bool m_bHasPrintOptions;
bool m_bPlugInsActive;
@@ -71,14 +71,14 @@ struct SfxViewShell_Impl
bool m_bGotOwnership;
bool m_bGotFrameOwnership;
SfxScrollingMode m_eScroll;
- USHORT m_nFamily;
+ sal_uInt16 m_nFamily;
::rtl::Reference<SfxBaseController> m_pController;
::std::auto_ptr< ::svt::AcceleratorExecute > m_pAccExec;
com::sun::star::uno::Sequence < com::sun::star::beans::PropertyValue > aPrintOpts;
::rtl::Reference< SfxClipboardChangeListener > xClipboardListener;
::boost::shared_ptr< vcl::PrinterController > m_pPrinterController;
- SfxViewShell_Impl(USHORT const nFlags);
+ SfxViewShell_Impl(sal_uInt16 const nFlags);
};
#endif
diff --git a/sfx2/source/control/ctrlitem.cxx b/sfx2/source/control/ctrlitem.cxx
index 9376b81fa0ff..cef5d7043cc5 100644
--- a/sfx2/source/control/ctrlitem.cxx
+++ b/sfx2/source/control/ctrlitem.cxx
@@ -45,7 +45,7 @@ DBG_NAME(SfxControllerItem);
//--------------------------------------------------------------------
#ifdef DBG_UTIL
-void SfxControllerItem::CheckConfigure_Impl( ULONG nType )
+void SfxControllerItem::CheckConfigure_Impl( sal_uIntPtr nType )
{
// echter Slot? (also kein Separator etc.)
if ( !nId )
@@ -77,9 +77,9 @@ SfxControllerItem* SfxControllerItem::GetItemLink()
//--------------------------------------------------------------------
-// returns TRUE if this binding is really bound to a function
+// returns sal_True if this binding is really bound to a function
-BOOL SfxControllerItem::IsBound() const
+sal_Bool SfxControllerItem::IsBound() const
{
DBG_MEMTEST();
DBG_CHKTHIS(SfxControllerItem, 0);
@@ -90,13 +90,13 @@ BOOL SfxControllerItem::IsBound() const
// returns the associated function-id or 0 if none
-// USHORT SfxControllerItem::GetId() const;
+// sal_uInt16 SfxControllerItem::GetId() const;
//====================================================================
// registeres with the id at the bindings
-void SfxControllerItem::Bind( USHORT nNewId, SfxBindings *pBindinx )
+void SfxControllerItem::Bind( sal_uInt16 nNewId, SfxBindings *pBindinx )
{
DBG_MEMTEST();
DBG_CHKTHIS(SfxControllerItem, 0);
@@ -115,7 +115,7 @@ void SfxControllerItem::Bind( USHORT nNewId, SfxBindings *pBindinx )
pBindings->Register(*this);
}
-void SfxControllerItem::BindInternal_Impl( USHORT nNewId, SfxBindings *pBindinx )
+void SfxControllerItem::BindInternal_Impl( sal_uInt16 nNewId, SfxBindings *pBindinx )
{
DBG_MEMTEST();
DBG_CHKTHIS(SfxControllerItem, 0);
@@ -261,7 +261,7 @@ SfxControllerItem* SfxControllerItem::ChangeItemLink( SfxControllerItem* pNewLin
// changes the id of unbound functions (e.g. for sub-menu-ids)
-void SfxControllerItem::SetId( USHORT nItemId )
+void SfxControllerItem::SetId( sal_uInt16 nItemId )
{
DBG_MEMTEST();
DBG_CHKTHIS(SfxControllerItem, 0);
@@ -286,7 +286,7 @@ SfxControllerItem::SfxControllerItem():
// creates a representation of the function nId and registeres it
-SfxControllerItem::SfxControllerItem( USHORT nID, SfxBindings &rBindings ):
+SfxControllerItem::SfxControllerItem( sal_uInt16 nID, SfxBindings &rBindings ):
nId(nID),
pNext(this),
pBindings(&rBindings)
@@ -364,7 +364,7 @@ void SfxStatusForwarder::StateChanged
//--------------------------------------------------------------------
SfxStatusForwarder::SfxStatusForwarder(
- USHORT nSlotId,
+ sal_uInt16 nSlotId,
SfxControllerItem& rMaster ):
SfxControllerItem( nSlotId, rMaster.GetBindings() ),
pMaster( &rMaster )
@@ -448,7 +448,7 @@ SfxMapUnit SfxControllerItem::GetCoreMetric() const
{
SfxShell *pSh = pDispat->GetShell( pServer->GetShellLevel() );
SfxItemPool &rPool = pSh->GetPool();
- USHORT nWhich = rPool.GetWhich( nId );
+ sal_uInt16 nWhich = rPool.GetWhich( nId );
return rPool.GetMetric( nWhich );
}
}